# Behind the scenes: How we host Ars Technica, part 1
## Join us on a multipart journey into our place in the cloud!
## Information:

+ Link: https://arstechnica.com/information-technology/2023/07/ars-on-aws-01/
+ Source: Ars Technica
+ Author: Lee Hutchinson
+ Date published: 19 July 2023, 13:00
+ Date scraped: 19 July 2023, 14:01

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/07/opening-the-ars-vault-760x380.jpg)







A bit over three years ago, just before COVID hit, we ran a long piece on [the tools and tricks that make Ars function without a physical office](https://arstechnica.com/information-technology/2020/01/no-office-no-problem-how-ars-technicas-remote-workers-work/). Ars has spent decades perfecting how to get things done as a distributed remote workforce, and as it turns out, we were even more fortunate than we realized because that distributed nature made working through the pandemic more or less a non-event for us. While other companies were scrambling to get work-from-home arranged for their employees, we kept on trucking without needing to do anything different.


However, there *was* a significant change that Ars went through right around the time that article was published. January 2020 marked our transition away from physical infrastructure and into a wholly cloud-based hosting environment. After years of great service from the folks at Server Central (now [Deft](https://deft.com/)), the time had come for a leap into the clouds—and leap we did.


There were a few big reasons to make the change, but the ones that mattered most were feature- and cost-related. Ars fiercely believes in running its own tech stack, mainly because we can iterate new features faster that way, and our community platform is unique among other Condé Nast brands. So when the rest of the company was either moving to or already on Amazon Web Services (AWS), we could hop on the bandwagon and take advantage of Condé’s enterprise pricing. That—combined with no longer having to maintain physical reserve infrastructure to absorb big traffic spikes and being able to rely on scaling—fundamentally changed the equation for us.


In addition to cost, we also jumped at the chance to rearchitect how the Ars Technica website and its components were structured and served. We were using a “virtual private cloud” setup at our previous hosting—it was a pile of dedicated physical servers running VMWare vSphere—but rolling everything into AWS gave us the opportunity to reassess the site and adopt some solid reference architecture.


## Cloudy with a chance of infrastructure


And now, with that redesign having been functional and stable for a couple of years and a few billion page views (really!), we want to invite you all behind the curtain to peek at how we keep a major site like Ars online and functional. This article will be the first in a four-part series on how Ars Technica works—we’ll examine both the basic technology choices that power Ars and the software with which we hook everything together.


This first piece, which we’re embarking on now, will look at the setup from a high level and then focus on the actual technology components—we'll show the building blocks and how those blocks are arranged. Another week, we’ll follow up with a more detailed look at the applications that run Ars and how those applications fit together within the infrastructure; after that, we’ll dig into the development environment and look at how Ars Tech Director Jason Marlin creates and deploys changes to the site.


Finally, in part 4, we’ll take a bit of a peek into the future. There are some changes that we’re thinking of making—the lure (and price!) of 64-bit ARM offerings is a powerful thing—and in part 4, we’ll look at that stuff and talk about our upcoming plans to migrate to it.


## Ars Technica: What we’re doing


But before we look at what we want to do *tomorrow,* let’s look at what we’re doing *today.* Gird your loins, dear readers, and let’s dive in.


To start, here’s a block diagram of the specific AWS services Ars uses. It’s a relatively simple way to represent a complex interlinked structure:


[![A high-level diagram of the Ars AWS setup.](https://cdn.arstechnica.net/wp-content/uploads/2023/07/ars-aws-vpc-and-ci-cd-300-1.png)](https://cdn.arstechnica.net/wp-content/uploads/2023/07/ars-aws-vpc-and-ci-cd-300-1.png) / A high-level diagram of the Ars AWS setup.Lee Hutchinson


Ars leans on multiple pieces of the AWS tech stack. We’re dependent on an [Application Load Balancer](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/introduction.html) (ALB) to first route incoming visitor traffic to the appropriate Ars back-end service (more on those services in part 2). Downstream of the ALB, we use two services called [Elastic Container Services](https://aws.amazon.com/ecs/) (ECS) and [Fargate](https://aws.amazon.com/fargate/) in conjunction with each other to spin up Docker-like containers to do work. Another service, [Lambda](https://aws.amazon.com/lambda/), is used to run cron jobs for the WordPress application that forms the core of the Ars website (yes, Ars runs WordPress—we’ll get into that in part 2).







!["It is a Fargate! It is different from that movie which I have never seen!"](https://cdn.arstechnica.net/wp-content/uploads/2023/07/athf-fargate.jpg)"It is a Fargate! It is different from that movie which I have never seen!"Warner Bros / Discovery Networks


Below all that, we’re using the [Aurora database service](https://aws.amazon.com/rds/aurora/) to provide MySQL databases for the site to use and [Elastic File System](https://aws.amazon.com/efs/) (EFS) to provide some persistent storage to various bits. Then, filling out the cloud dance card, we lean on good ol’ memcached (via [ElastiCache](https://aws.amazon.com/elasticache/)) for all of our caching and ElasticSearch (via [OpenSearch](https://aws.amazon.com/opensearch-service/)) for on-site search services. Yes, the naming of some of the tools is a bit of a mess. Welcome to AWS.


We will dig a little deeper into each of these blocks shortly, but first, folks already super familiar with AWS may note that these tools have a commonality: They are all “serverless” technology. Understanding how everything fits together requires understanding exactly what “serverless” means in this context, so let’s settle on a practical definition.


## When is a server not a server?


As a certified old-school graybeard sysadmin, “serverless” is a term that’s taken me a while to fully grok because, like most modern computing buzzwords, it’s a bit of a fib. “Serverless” technology doesn’t mean there are no servers involved—remember that most true of truisms: *There’s no such thing as “the cloud.” It’s all just someone else’s servers.* This doesn't mean we will be doing this somehow without servers—perhaps by *forbidden magic* or something.


However, the “serverless” bit of “serverless” here *does* mean that we generally don’t need to *care* about those servers—we are approaching the problem through a few layers of abstraction. Our requirements here are to run some applications, and rather than addressing those requirements first in terms of infrastructure (a “bottom-up” approach), with a serverless approach, we address those requirements in terms of the applications themselves and the amount of compute resources they take up.


That sounds like kind of standard system design, but in practice, it’s not. Look, for example, at traditional self-hosted WordPress, and contrast it with how one runs WordPress in a serverless context.


For standard hosted WordPress, you get yourself a host of some kind—be it a physical server, a VPS, an [AWS Elastic Compute Cloud instance](https://aws.amazon.com/ec2/), or whatever you’d like—and copy the WordPress application to a directory. You set up a web server application like Apache or Nginx; you configure a PHP handler like php-fpm; you make available a database like MySQL or MariaDB; and then the server runs those applications using its own CPU, RAM, disk, and networking. Everyone understands this. This is how computers have worked forever.


Going serverless has the same functional result—a working WordPress instance that serves up pages to visitors—but we get there a different way. Instead of a single monolithic server being the box inside of which all our processes run and speak to each other and from which our processes are assigned resources, AWS’s serverless tools effectively allow us to create processes in a “void”—that is, without any kind of user-visible server containing everything. From our perspective, our application doesn’t run on a server at all—it just kind of *runs.*


(Are there actual servers in the AWS back-end underpinning all this work? Obviously, yes. Do we need to care about the mapping between those servers and our serverless execution environment? No. Well, a little, but only to the extent that we must pay for what we use, so we want to be mindful of how much RAM, CPU, storage, and networking we consume.)


## Going with the flow


To visualize things a bit better, let’s follow an incoming request from a visitor hitting up the Ars front page. You type `https://arstechnica.com` into your browser bar and hit enter, and your bits fly at more or less the speed of light between routers and eventually get ingested by AWS.


The first thing that happens is your traffic hits our application load balancer. The [ALB](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/introduction.html) is a specific AWS product offering—it’s a [layer 7](https://en.wikipedia.org/wiki/OSI_model#Layer_7:_Application_layer)-aware load balancer and proxy that watches HTTP and HTTPS and directs traffic to the right place.


We’re making our determination on what should go where based on the hostname being requested by the visitor—so if you’re looking to load the Ars front page, the ALB sniffs that out based on the URL you’re asking for and then sends you on to the appropriate task (more on ECS tasks in a moment). But existing at layer 7 and being aware of the HTTP headers of each request means the ALB can do [a ton of other useful things](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/introduction.html), including redirects and custom responses, all based on what’s in the HTTP request. (We're also using the ALB for SSL/TLS termination, for example.)





[![This shows the rules we have set up for our Application Load Balancer. It listens on port 80 for HTTP traffic and redirects to 443, and it listens on 443 for HTTP traffic and forwards that traffic to a running ECS task.](https://cdn.arstechnica.net/wp-content/uploads/2023/07/ars_alb_r.png)](https://cdn.arstechnica.net/wp-content/uploads/2023/07/ars_alb_r.png) / This shows the rules we have set up for our Application Load Balancer. It listens on port 80 for HTTP traffic and redirects to 443, and it listens on 443 for HTTP traffic and forwards that traffic to a running ECS task.


Onward! In a normal WordPress install, after the load balancer is the point where your incoming traffic would then encounter the actual web server application that’s been configured to serve up WordPress. And, indeed, that’s what happens here—a few Nginx listeners are standing by. But where do they run? Doesn’t Nginx have to *run* on something?


Nginx—and a few other things, including and especially the all-important php-fpm—run inside of structures called “tasks,” which you can think of as a Docker-like host that bundles together Docker-esque containers, which in turn run our applications. These “task” bundles are configured and built with AWS’s Elastic Container Service, which gives us a way to group together (or “containerize”) one or more applications so that they can run inside a tightly controlled little resource box. (I'm saying things like "Docker-esque" and "Docker-like" here because [ECS actually *does* use Docker under the hood](https://docs.aws.amazon.com/AmazonECS/latest/userguide/create-container-image.html)—for now, at least. And for folks who have heard of Docker but still aren't completely sure what it does, think of a “container” in this context like a lightweight virtual machine that consists of [user space](https://en.wikipedia.org/wiki/User_space_and_kernel_space) only—no kernel.)


## An aside about ECS and tasks


All of the pieces in the tech stack are important, but ECS is one of the most important of all. Our current design is based on containerization, and [ECS is what makes that possible](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/Welcome.html).


ECS is built around Docker containers (though I’m trying to be careful and differentiate between “ECS containers” and “Docker containers” in this guide because in practice, the two aren’t exactly the same, even though we are technically using the ECS tool to launch Docker containers). The idea is that to use ECS, you divide the functional components of your solution up into one or more executable “tasks”—remember that a “task” in ECS terminology means “one or more containers running together”—and then stand up and tear down containers as needed to handle your workload.


Actually constructing an ECS container is a familiar process to folks who have used Docker before because [you can use standard tools](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task_definitions.html) like Docker Compose to make it happen. Putting together a container is straightforward and works exactly like configuring any other Docker container with the same tools, and once you have your containers constructed, you [create tasks](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task_definitions.html) to tell ECS how the containers are linked together and how they should be launched.


[![This screen shows the overall status of our main service, to which all of our tasks belong.](https://cdn.arstechnica.net/wp-content/uploads/2023/07/arx-prod-service-r.png)](https://cdn.arstechnica.net/wp-content/uploads/2023/07/arx-prod-service-r.png) / This screen shows the overall status of our main service, to which all of our tasks belong.


At Ars, we have one master task called `arx-production-web-apps` (or just “Arx,” in Ars dev lingo) that contains everything we need to run the site. The Arx task runs four containers:


* `arx_nginx`
* `arx_acta_php`
* `arx_civis_php`
* `arx_taberna_php`


The first container, `arx_nginx`, runs an Nginx reverse proxy. Incoming HTTP traffic hits Nginx first, and Nginx then routes the traffic appropriately to one of the three PHP containers. The three PHP containers run php-fpm and actually do the dynamic processing and page rendering for Ars and its components.


Those PHP containers are `arx_acta`, which runs the whole WordPress PHP application; `arx_civis`, which runs the Xenforo-powered [OpenForum](https://arstechnica.com/civis/); and `arx_taberna`, which runs the [Ars web store](https://arstechnica.com/store/) (where you can purchase fine merchandise like a [Moonshark t-shirt](https://arstechnica.com/store/product/moonshark-shirt/) or an [Ars mug](https://arstechnica.com/store/product/20th-anniversary-mug/)!)


Depending on the time of day, more tasks will be invoked to handle load as it ramps up. I’m writing this at about 7:00 am US Eastern Time early in the morning of July 12, and right now, the AWS console says we’re running 24 instances of the “Arx” task. That usually scales up to 30-ish instances by 9:00 am Eastern as more people turn on their computers and hit up the Ars homepage for news. (As more tasks are added, the Application Load Balancer seamlessly distributes traffic between them to prevent any one task’s processes from becoming saturated.)


But wait—how *do* those Arx tasks actually get invoked and destroyed? What service is monitoring these things and making all these decisions?












## Tags:
***urls***: https://arstechnica.com

### Autogenerated tags:
[[aws]] [[ecs]] [[wordpress]] [[serverless”]] [[http]] [[serverless]] [[php]] [[nginx]] [[docker-like]]
