# Hosting Ars, part three: CI/CD, or how I learned to stop worrying and love DevOps
## This time we discuss how we manage, update, and deploy the code that makes Ars work.
## Information:

+ Link: https://arstechnica.com/information-technology/2023/08/ars-on-aws-03/
+ Source: Ars Technica
+ Author: Jason Marlin & Lee Hutchinson
+ Date published: 02 August 2023, 13:00
+ Date scraped: 02 August 2023, 14:01

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/08/GettyImages-1367728715c-760x380.jpg)







One of the most important things to happen in the evolution of development over the past many years is the widespread adoption of [continuous integration and continuous deployment](https://www.redhat.com/en/topics/devops/what-is-ci-cd), or CI/CD. (Sometimes the "CD" stands for "continuous delivery," depending on who you're talking to.)


It's a concept that jettisons a lot of older ideas about how systems should be managed and instead gives you a way to update code and integrate changes as live rolling deployments while ensuring that the new code is tested and slots in smoothly with stuff that's already running. A properly architected CI/CD pipeline means you can get code changes into production faster and with fewer errors. But what does that look like in practice?


It looks like Ars Technica, because we've adopted a CI/CD workflow to take full advantage of the flexibility afforded us by serverless cloud hosting. Welcome to part three of our four-part series on how we host Ars—here, we’re going to swing away from the "ops" side of "DevOps" and peer more closely at the "dev" part instead. Join us for a look behind the curtain at how Ars uses CI/CD in both our deployed applications and our infrastructure management!


## Version control is not optional


For the benefit of folks who only do the "ops" part of DevOps, let's get a working definition going for "[version control](https://en.wikipedia.org/wiki/Version_control)," as the term underpins our entire approach toward maintaining code. When we say "version control" in this context, we're talking about a method by which we're able to track changes made to our production codebase—that is, the repository of files that makes Ars function.


Ensuring that production codebase is subject to some form of version control is a lot like turning on "track changes" in Word: the version control system keeps a record of every change made to every file, along with a correlated list of who made the change and when it happened. Version control is a critical component of most large-scale IT projects, and in some cases, it's even a [mandated regulatory requirement](https://en.wikipedia.org/wiki/Sarbanes%E2%80%93Oxley_Act).


But version control is a hard problem to solve, and many of the solutions that are common now—including and especially [Git](https://en.wikipedia.org/wiki/Git)—are still relatively young. Not that long ago, there was a time I don’t remember with fondness—a time in which you edited code in a text editor and then FTP’d it to a production server. This was a low and filthy era, rife with lost changes, production crashes, and ad-hoc backups with names like `oops-1997-05-21.tar.gz`. To be sure, even back in those primitive days, there were bearded wizards that spoke of inscrutable technologies like CVS ([Concurrent Versions System](https://en.wikipedia.org/wiki/Concurrent_Versions_System), not the pharmacy), but such things were conspicuously absent from most folks' experience within the burgeoning universe of web development.


While many of us probably recall [SVN repositories](https://en.wikipedia.org/wiki/Apache_Subversion) (and with many thoughts and prayers to those of you still dealing with SVN), it wasn’t until Git that version control gained massive popularity. Why? In part because tools like Git and GitHub made it dead simple to create and maintain repositories—just [type a few commands](https://git-man-page-generator.lokaltog.net), and you’re up and running. Most of the world’s developers now maintain code repositories on GitHub, and Ars is no exception.


## How do changes flow from GitHub into deployed applications?


Well, we start by firing up our favorite FTP client, Transmit. I kid, I kid—but Transmit was (and apparently [still is](https://panic.com/transmit/)) an awesome app. For real, now: We start by working on a particular branch in one of our repositories. Remember from [our previous installments](https://arstechnica.com/information-technology/2023/07/ars-on-aws-01/) that Ars is composed of four main applications, each running in its own container inside AWS ECS tasks:


* Arx: Our local Docker Compose development setup and Nginx server container
* Acta: The main WordPress application
* Civis: Our discussion forum software
* Taberna: Our e-commerce and subscription system


Each of these applications has its own repository on GitHub. When large changes are made, a new branch is created. Eventually, that new feature branch will be merged into a staging branch via a pull request. After testing, staging will be merged into the main branch with another pull request.







## Branches, merges, and pull requests, oh my!


In version control terms, a "branch" is simply a named deviation from the main code repository. For example, if we decided to replace the Ars logo with the letter "X"—wait, that's too relevant, let's say the letter "Y"—we would start by checking out a new branch along the lines of this: `git checkout -b feature-l33t-new-ars-logo`.


That command creates a clean copy of the main repository—one we can start messing with in our local development environment without having to worry about stepping on anything in production. Once we've completed an exhaustive find-and-replace to change all the places where the code says `ars-technica-logo.png` to `y-technica-logo.png`, we're ready to "commit" the change to the branch. Committing does not make your changes live in production—instead, it's just a way to describe your changes. In this case, our commit might be something like `git commit -m "Sweet new logo for Ars - Y is the future"`.


Next up, we need to actually get the change from our local development environment up into the GitHub repository. In Git terms, we need to "push" our changes. This is accomplished with, perhaps unsurprisingly, the `git push` command. After that, the code exists in the GitHub repo, and the next step—if we feel good about what we've coded—is to test it in a staging environment. Doing this means we need to get our changes from the `feature-l33t-new-ars-logo` branch and put them somewhere—like our `staging` branch. There are many ways to integrate code between branches, but we like the formality of doing things with [pull requests](https://docs.github.com/en/pull-requests/collaborating-with-pull-requests/proposing-changes-to-your-work-with-pull-requests/about-pull-requests), which lets us merge our new code into an existing branch and also leaves us with good documentation around every change. A pull request could consist of one or hundreds of commits that took place during the development of the feature branch.


Git will automatically flag any "conflicts" when you merge branches. A conflict usually arises when someone has committed newer changes to the same files affected by the new feature branch. Working through large conflicts can be a nightmare, which is why it's important to work as granularly as possible when creating new features—only check out what you need, when you need it, and be mindful of where others are working. Ideally, you introduce as little new and disruptive code as possible—and, fortunately, our new Y logo fits the bill.


[![Perfection. Nobody tell Aurich.](https://cdn.arstechnica.net/wp-content/uploads/2023/07/y-technica-logo.png)](https://cdn.arstechnica.net/wp-content/uploads/2023/07/y-technica-logo.png) / Perfection. Nobody tell Aurich.


When code is added to key branches we have set up, like `staging` or `main`, a series of automated events are kicked off. These all start with [linting](https://en.wikipedia.org/wiki/Lint_(software)) and testing. Linting—a term that refers to a static check of one's code and configuration files to make sure there aren't any typos or other issues—ensures that submitted code conforms to our internal styles and practices. After linting, testing ensures that the major features and functions of the applications are all continuing to produce the desired results so that you don’t introduce unanticipated problems in other areas of your software when you push new code.


On each push, GitHub fires up a build system that runs the linting and testing commands you specify, using a simple YML configuration file and [GitHub Actions](https://docs.github.com/en/actions/quickstart). It’s worth noting that these tests could also run inside AWS CodeBuild, but GitHub’s build system is very fast and automatically integrated with the repository user interface, so we can see at a glance what horrors we’ve introduced with our latest pulls.


[![Oops! Well, dang, I guess we're not getting a new logo today.](https://cdn.arstechnica.net/wp-content/uploads/2023/07/pasted-image-0.png)](https://cdn.arstechnica.net/wp-content/uploads/2023/07/pasted-image-0.png) / Oops! Well, dang, I guess we're not getting a new logo today.


Once our tests have passed, GitHub uses a [webhook](https://en.wikipedia.org/wiki/Webhook) to notify AWS that we've got some code to deploy to production, and this is where the real fun begins.





## AWS CodePipeline and CodeBuild


[CodePipeline](https://aws.amazon.com/codepipeline/) is an AWS tool that allows you to take code from a repository and pass it around to different services within AWS (hence the "pipeline" part!) with an eye toward helping out with building and deployment tasks. Additionally, at least in our case, changes to some key GitHub repositories and branches will also kick off a [CodeBuild](https://aws.amazon.com/codebuild/) process.


CodeBuild is a service that actually fires up an instance of preconfigured build environments, inside of which code will be compiled to your specs. There are [many such environments to choose from](https://docs.aws.amazon.com/codebuild/latest/userguide/available-runtimes.html). The image and build instructions are read from a `buildspec.yml` file in each application’s root directory. (Note that when we say "root directory" here, we mean that the `buildspec.yml` file is stored in the root of the GitHub repo.)


This build file tells CodeBuild what runtimes we need (e.g., "Please provide PHP 8.1 and Node.js 18") and breaks down into a series of build phases that are [fairly easy to understand](https://docs.aws.amazon.com/codebuild/latest/userguide/available-runtimes.html) if you’ve seen YAML before. These `buildspec.yml` files can become extremely complex and even include other build files, but our setup for the main WordPress application is fairly straightforward:


1. Log in to our AWS [ECR](https://aws.amazon.com/ecr/) (Elastic Container Repository)
2. Use [Composer](https://getcomposer.org/) to install any defined PHP packages we need
3. Use [npm](https://www.npmjs.com/) to install and build any frontend packages, minify our Javascript, etc.
4. Delete a lot of unnecessary files (we don’t need that `.gitignore` or `README` in production, do we?)
5. Run the `docker build` command, which will create our image per a project-specific [Dockerfile](https://docs.docker.com/engine/reference/builder/)
6. And finally, *push* this new image to the container repository, where it can be later pulled down by ECS


Whew! That sounds like a lot (and it is!), but it’s mostly a "design once and rarely edit" setup. There’s more involved with tagging and storing Docker images in ECR, but this gives you the general overview. (You can think of ECR like our own isolated version of [DockerHub](https://hub.docker.com/).) Once CodeBuild is done, it returns its results back to CodePipeline, which will continue its execution.


So now we’ve committed code, tested it, built our final Docker image with all our application files copied over, and pushed that image to ECR, where it can be accessed by a simple `docker pull` command. What’s next? From our [first installment](https://arstechnica.com/information-technology/2023/07/ars-on-aws-01/), we know our newly built Docker images need to eventually end up living on one of our Fargate ECS clusters as containers in a “task,” but *how,* exactly?


[![This is how we do it. (Mostly.)](https://cdn.arstechnica.net/wp-content/uploads/2023/07/ars-aws-ci-cd.png)](https://cdn.arstechnica.net/wp-content/uploads/2023/07/ars-aws-ci-cd.png) / This is how we do it. (Mostly.)





## Enter AWS CodeDeploy and blue/green deployments


If nothing else has piqued your interest about this approach to CI/CD, I think [blue/green deployments](https://en.wikipedia.org/wiki/Blue%E2%80%93green_deployment) may be the “Excelsior!” moment. It certainly was for me. Imagine: Even after running successful tests and builds, you eventually get to a point where you must flip a switch, finally saying goodbye to your stable production environment and puckering all orifices while you wait for the new deployment to come online and take over production work.


This was the way things were for us a few years ago—production changes were made by deploying code using a makeshift Debian repository (which was kind of a genius approach—hat tip to Ars developer emeritus Lee Aylward). Even with Fargate managing the tasks, a *lot* can go wrong. An errant incorrect environment variable, something wrong with the underlying provisioning service, an unintended change that passed all the tests but still breaks the site—there are a million potential problems.


![Beholding the ghosts of past deployments failed. Anything could go wrong—<em>"...an undigested bit of beef, a blot of mustard, a crumb of cheese, a fragment of underdone potato..."</em>](https://cdn.arstechnica.net/wp-content/uploads/2023/07/PatrickStewartScrooge.webp)Beholding the ghosts of past deployments failed. Anything could go wrong—*"...an undigested bit of beef, a blot of mustard, a crumb of cheese, a fragment of underdone potato..."*


Blue/green is one of multiple strategies provided out-of-the-box by [AWS CodeDeploy](https://aws.amazon.com/codedeploy/features/), and this is where it saves the day. With blue/green deployment, a completely new target group containing your updated container(s) will be spun up in parallel to your existing production application, containing an identical number of tasks but accessible through an alternate port on the application load balancer. Thus, you can peruse the new stuff on the alternate port to your heart’s content until you’re completely satisfied that it’s ready for public traffic. From here, it’s a simple flip of the switch to swap public traffic to the new target group. This is one part of our CI/CD process that we do manually, for obvious reasons.


For folks who require a car analogy to properly grok a tech concept (I see you raising your hand back there, Lee!), think of blue/green deployments as being a bit like the DevOps take on a [dual-clutch transmission](https://www.youtube.com/watch?v=lFAtc-zOKZs)—the transition between gears goes a lot faster in a DCT because the next gear change is already being handled by the other clutch while you're still accelerating, just as we get our replacement environment built and brought to hot standby while the current environment runs. When it's time to shift—gears or production containers!—the changeover happens much more quickly because all the work to accomplish the transition, along with the validation that it will be successful, has already happened. You just failover between clutches in the DCT and between "blue" and "green" environments for Ars.


There are competing deployment strategies, to be sure—such as slowly shifting traffic to your new setup over time. Personally, I love blue/green for high-volume websites because your commitment is zero until you’re happy with how everything is running. Even then, you have the option to roll your deployment back to the previous version, which—as long as you haven’t terminated its tasks—is still running in parallel. Failing back, if one needs to do it, takes only seconds. The entire process greatly reduces anxiety associated with deploying large changes, which any developer will be able to relate to.


While we’re talking anxiety, nothing has caused more insomnia among developers than the state of one's infrastructure. ("It's 10 pm—do *you* know where your servers are?") We’ll discuss next how we’ve managed to reduce stress on that front.












## Tags:


### Autogenerated tags:
[[github]] [[aws]] [[ci/cd]] [[codebuild]] [[blue/green]] [[ecr]] [[devops]] [[ecs]] [[linting]] [[codepipeline]]
