# How big is the risk that someone will hack an EV charging network?
## EV chargers are on the spectrum of the Internet of Things, and that means risk.
## Information:

+ Link: https://arstechnica.com/cars/2022/07/ev-charging-networks-create-a-tempting-target-for-cyberattacks/
+ Source: Ars Technica
+ Author: Gordon Feller
+ Date published: 26 July 2022, 17:49
+ Date scraped: 28 July 2022, 09:10

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2022/07/little-hacker-sittiing-in-ev-charger-760x380.jpg)







The [Infrastructure Investment and Jobs Act](https://www.congress.gov/bill/117th-congress/house-bill/3684), as passed by Congress last November, authorizes $7.5 billion to help meet US President Joe Biden's goal of installing 500,000 stations by 2030. Biden aims to have EVs represent half of all new vehicles being sold in the US by 2030. But as the number of stations increases, the number of vulnerabilities does as well.


For the past several years, hackers have been busy aiming their attacks at electrical system [vulnerabilities](https://arstechnica.com/information-technology/2022/03/russian-state-hackers-are-exploring-cyberattack-options-on-us-white-house-says/). In the case of charging stations, some of these soft spots are located inside the stations; some are located inside the equipment that controls connections between the grid and the station; and still, others are inside assets that sit on the grid side of the relationship, and these are mostly owned by utilities. Europe-based wind power companies (Deutsche Windtechnik AG, Enercon GmbH, and Nordex SE) have suffered attacks focused on stopping the flow of electrons, identity theft attacks, and stolen payments. In most cases, the results can be service disruptions affecting customers and revenue reductions for the providers of electrons and/or asset owners.


Hackers perpetually seek out ways to use any and all system vulnerabilities to their [maximum advantage](https://arstechnica.com/information-technology/2022/05/how-safe-is-societys-critical-infrastructure-from-infosec-attacks/). This is a problem for the consumer, just as it is for commercial enterprises. Added to the stresses created by several types of hacker disruptions—physical destruction; electronic jamming; creating a "Denial of Service"—are concerns about weak control systems. From his perch at PlugInAmerica.org, Ron Freund worries that the existing supervisory control and data acquisition hardware is primate.


"It doesn't handle the simple faults gracefully, and is not reliable, much less scalable. But it also is not yet on the Internet, so is inaccessible (for the most part). In fact, it's scary how primitive some of these systems still are," Freund told me.


## Protect your backend


Situated at the heart of EV infrastructure are stations connected to a central control unit, commonly referred to as "the backend." This backend communicates over a wireless network using the same technology as a SIM card (in other words, it uses machine-to-machine communications). Stations collect sensitive data such as payment data, location data, and demographic data that might include email addresses and IP numbers. Since a mobile app or an RFID card is used to access the station, sensitive data is also collected on the apps, including location data and online behavior history.


According to Thomas Russell of the National Cybersecurity Center, "this data can be used to find patterns of daily routines and location data as well as private information." Networked stations have obvious advantages for operators, who can monitor usage and reliability in real time, but being networked means being vulnerable.


According to Joe Marshall at Cisco Talos, "The most vulnerable elements of an electric vehicle charging station will usually be the EV management system (aka the EVCSMS). Vendors who own these stations need to stay connected with them over the Internet to process payments, perform maintenance, and make their services available to EVs." Consequently, this can expose their stations to attackers who may seek to exploit that EVCSMS.


Marshall is distressed that EVCSMSes are "vulnerable in numerous ways." Many are developed with poor security practices—from hard-coded (and thus stealable) credentials to poor security code development that lets attackers exploit management interfaces to compromise the system. He thinks that "this is not dissimilar from many modern IoT devices, like web cameras or home routers" that traditionally have poorly designed security. EV management system is incredibly similar to other IoT products and markets, as well.







The Critical Infrastructure Security Agency (CISA) is the US federal reporting agency responsible for security disclosures. CISA issued several security alerts on EVCS systems. There are many companies in the EVCS space, Marshall says, that, looking through that companies list, "it's difficult to say who is aware of their security vulnerabilities, though certainly if there's a Common Vulnerabilities and Exposures (CVE) issued, you're aware that vulnerabilities are in your product."


Looking at the full breadth of the problem, Marshall doesn't seem to have much good news to offer.


"Outside of the known security alerts, there does not seem to be much additional security research occurring on EVCS or their management systems," Marshall said. In his view, the prognosis going forward "is not great," and he cites "a rush of companies [that] want to join the EVCS market as electric cars become more prominent on our roads. These companies typically make security an afterthought, if at all, in their products."


[![A Kia Niro charges at an Electrify America charging station. This actual charging session was free due to an AWS issue that prevented the Electrify America charger from asking for payment. ](https://cdn.arstechnica.net/wp-content/uploads/2022/05/Kia-NIro-charging-980x601.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2022/05/Kia-NIro-charging.jpg) / A Kia Niro charges at an Electrify America charging station. This actual charging session was free due to an AWS issue that prevented the Electrify America charger from asking for payment. Jonathan Gitlin


## Do we need a cybersecurity standard?


Marshall predicts that government regulatory action is certainly a possibility, where a minimum-security standard must be met—and will be enforced. What might be a more likely solution is that, as the market matures, so does security within the products. Third-party solutions may arise to help companies consider security threats and ways to develop EVCS/MS that incorporate best security practices into its development cycle.


At the [Electric Power Research Institute](https://www.epri.com/) (EPRI), Sunil Chhaya has been focused on two primary issues. "There is no uniform cybersecurity standard to which they can be specified, designed, built, or tested. Even if individual information links are made cybersecure, there is no assurance that system as a whole is cybersecure," Chhaya said.


Chhaya advocates for a systematic approach where "standards organizations, regulators, trade associations, research labs, as well as equipment and technology providers must work together for specifying, designing, building, testing, and deploying systems, and not just parts of the system, that are cybersecure," he said. Indeed, EPRI has created an EV Charging Cybersecurity Management Platform that will soon be available for public use. Developed together with utilities, third-party providers, national labs, equipment manufacturers, and the EV manufacturers, it allows a practitioner to configure a given charging infrastructure topology, assess risks and 'attack surfaces,' and provide mitigation solutions and strategies on a system-wide basis by applying the industry best practices and patterns to the EV infrastructure case.


Clearly, everyone needs to be part of the solution: EV infrastructure vendors, chipset manufacturers, automotive OEMs and their suppliers, standards bodies such as IEEE, governments, and trade associations, to name just a few. The whole ecosystem needs to come together to ensure that cybersecurity isn't an afterthought.


One utility trade association, the [American Public Power Association](https://www.publicpower.org/) (APPA), is working on this problem. Alex Hofmann, APPA's vice president, points out that "any Internet-connected device poses a potential entry point for malicious intrusion—whether it's a large electric vehicle charging site or something as simple as a 'smart' thermostat or home security device."


APPA is focused on getting its member utilities to do "thoughtful deployments" of all Internet-connected devices with an emphasis on "shared responsibility" between manufacturers (who need to build in reasonable safeguards) and consumers (who need to do things like change default passwords and take other commonsense cyber hygiene steps). Government and academia also have a role as they can work on the edges to do things like identify threats and recommend patches, fixes, and safeguards for industry and consumers. Hofmann's big message to the utilities is a simple one: "The more ubiquitous web-connected devices are, the more vigilant we all need to be."






 




## Tags:
***email-adresses***: hisperch@pluginamerica.org

### Autogenerated tags:
[[ev]] [[cybersecurity]] [[evcs]] [[backend]] [[chhaya]] [[cybersecure]] [[appa]]
