# How we host Ars Technica in the cloud, part two: The software
## A deep dive into the applications and functions that keep Ars humming along in the cloud.
## Information:

+ Link: https://arstechnica.com/information-technology/2023/07/ars-on-aws-02/
+ Source: Ars Technica
+ Author: Lee Hutchinson
+ Date published: 26 July 2023, 13:00
+ Date scraped: 26 July 2023, 14:01

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/07/inside-the-ars-vault-760x380.jpg)







Welcome back to our series on how Ars Technica is hosted and run! [Last week, in part one](https://arstechnica.com/information-technology/2023/07/ars-on-aws-01/), we cracked open the (virtual) doors to peek inside the Ars (virtual) data center. We talked about our Amazon Web Services setup, which is primarily built around [ECS containers](https://aws.amazon.com/ecs/) being spun up as needed to handle web traffic, and we walked through the ways that all of our hosting services hook together and function as a whole.


This week, we shift our focus to a different layer in the stack—the applications we run on those services and how *they* work in the cloud. Those applications, after all, are what you come to the site for; you’re not here to marvel at a smoothly functioning infrastructure but rather to *actually read the site.* (I mean, I’m guessing that’s why you come here. It’s either that or everyone is showing up hoping I’m going to [pour ketchup on myself and launch myself down a Slip-'N-Slide](https://arstechnica.com/gadgets/2018/07/the-internet-demanded-partially-scientific-testing-of-ultraeverdry-in-hd/), but that was a one-time thing I did a long time ago when I was young and needed the money.)


## How traditional WordPress hosting works


Although I am, at best, a casual sysadmin, having hung up my pro spurs a decade and change ago, I do have some relevant practical experience hosting WordPress. I’m currently the volunteer admin for a half-dozen WordPress sites, including Houston-area weather forecast destination [Space City Weather](https://spacecityweather.com/) (along with its Spanish-language counterpart [Tiempo Ciudad Espacial](https://es.spacecityweather.com/)), the Atlantic hurricane-focused blog [The Eyewall](https://theeyewall.com/), my [personal blog,](https://blog.bigdinosaur.org/) and a few other odds and ends.


As hosted apps go, WordPress is less fussy than most, being one of the [most widely used web applications on planet Earth](https://kinsta.com/blog/wordpress-statistics/). If one is self-hosting, it takes more time to configure the web server and the PHP handler than it does to configure WordPress—you just download a zip file, uncompress it into your webroot, and browse to the proper URL. Specify your username and your MySQL information, and boom, you have a WordPress website ready to go!


In terms of functional flow, self-hosted WordPress requires basically four things:


* The WordPress PHP application itself
* A web server application, like Apache or Nginx, to actually serve things to the visiting reader
* A PHP handler, like php-fpm, to run the PHP code and create things for the web server application to serve
* A database for WordPress to store posts and other WP stuff in


In addition, the host on which you’re running WordPress needs to provide the following resources to let those applications actually have a place to function:


* Some amount of RAM
* Some amount of CPU time
* Some amount of disk space to hold our application’s code
* Some additional amount of disk space to hold our database
* Some *additional* additional amount of disk space to hold data created by our application users (like uploaded files)
* Some kind of network connectivity to the outside world


When it’s installed, WordPress exists primarily as a collection of tables in a MySQL database and a pile of files in your web root directory. My [personal blog's](https://blog.bigdinosaur.org) WordPress root directory, for example, looks like this:


[![If you've seen one WordPress root directory, you've seen 'em all.](https://cdn.arstechnica.net/wp-content/uploads/2023/07/wp-bash.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/07/wp-bash.jpg) / If you've seen one WordPress root directory, you've seen 'em all.Lee Hutchinson


Not terribly exciting. And there are no executable binary files in here or anything—they’re mostly just PHP files and require the magic of a PHP handler like php-fpm to actually *run* them. Otherwise, they just sit there.


The process of actually *running* those PHP files works like this: Let’s say you want to view a story on Ars Technica—like, say, [this one](https://arstechnica.com/gaming/2016/01/the-slowly-fading-art-of-flying-and-maintaining-cold-war-fighter-jets/). You click that link, and your web browser sends an HTTP GET request that, through the process described in [part one](https://arstechnica.com/information-technology/2023/07/ars-on-aws-01/), eventually arrives after a few milliseconds at the Ars Technica web backend. (To get specific, the request is serviced by one of the Nginx processes inside one of the many running `arx-production-web-apps` tasks).


Nginx looks at the path in the URL and figures out which part of it corresponds with the post you're asking to view, then tells php-fpm to begin executing PHP code from the WordPress `index.php` file, using the requested post as a parameter. The php-fpm process also causes queries to be run against MySQL—in this case, it pulls the requested post’s text and structure from the database. Additionally, php-fpm pulls URLs for images from the database so that your browser can request those images from our CDN. (A CDN, or "content delivery network," is a service that caches your stuff for you in lots of different places so your site will load faster—at least in theory.)


This all happens quickly, and it all happens within the confines of a single server—be it a physical box, a VPS, or whatever else you have. If we take away the server to contain all this within, how does it all hang together?


The short-short version is it hangs together because we use the tools from part one, and apparently, it all works because you’re reading these words right now. Science!







## How WordPress *et al* works in the cloud


The short-short version isn't terribly explicative, though, so let’s go with the regular short version instead—otherwise, the article will end here, and as much as I'd like to stop writing and go play *Diablo 4* or something, playing *Diablo 4* doesn't pay my mortgage. The regular short version is that while we’re not using [the WordPress-on-AWS reference architecture](https://docs.aws.amazon.com/whitepapers/latest/best-practices-wordpress/reference-architecture.html), we’re pretty close to it in many respects, and we believe our setup offers improvements to us over that design. In addition to being easier for us to manage, it’s also cheaper, and those are words that make any IT procurement manager’s eyes light up.


Let’s look at that block diagram of our hosting again:


[![A high-level diagram of the Ars AWS setup.](https://cdn.arstechnica.net/wp-content/uploads/2023/07/ars-aws-vpc-and-ci-cd-300-1.png)](https://cdn.arstechnica.net/wp-content/uploads/2023/07/ars-aws-vpc-and-ci-cd-300-1.png) / A high-level diagram of the Ars AWS setup.Lee Hutchinson


The differences between how requests flow in this serverless design start right when the request is ingested by the application load balancer ([ALB](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/introduction.html)) up front. I mentioned in part one that the ALB is a “layer 7-aware” load balancer, which in this context means that it’s particularly good at seeing the parts of incoming packets that correspond to [layer 7 of the OSI model](https://en.wikipedia.org/wiki/OSI_model#Layer_7:_Application_layer). That means our load balancer can read and apply filters based on HTTP and HTTPS characteristics, the URL in whole or in part, cookies included in the connection, and a few other layer 7 things.


After ensuring the traffic is appropriately encrypted (and after redirecting HTTP to HTTPS if it's not), the ALB does what it says on the tin and *balances the load.* It can send traffic to a number of destinations—called “targets” in AWS parlance—and those targets can take the form of IP addresses, EC2 instances, or Lambda functions (and we'll get to exactly what a Lambda function is in just a bit). For our use case, we’re using IP addresses—as you can see at the bottom of this screenshot, we’re sending traffic to a named group object called `arx-production-tg-webBG-2`:


[![Balancing those loads.](https://cdn.arstechnica.net/wp-content/uploads/2023/07/load-balancer.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/07/load-balancer.jpg) / Balancing those loads.


Chasing down this target group shows that it’s configured as a block of IP addresses within 10.1.0.0/16, which is the private CIDR block we use for production resource addressing:


[![](https://cdn.arstechnica.net/wp-content/uploads/2023/07/target-group.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/07/target-group.jpg)


As I’m writing this and capturing screenshots, there are currently 16 instances of the `arx-production-web-apps`  task running. Remember that “task” in this context means “Docker-like host running a bundle of containerized applications,” so each of those IP addresses in the target group corresponds with a running task.


The ALB does its load balancer thing and dispatches incoming HTTP sessions to different `arx-production-web-apps` tasks, identifying them by IP address. It chooses what task to send the next user session to by “round robin” balancing—that is, it iterates through the list in order. When a new session comes in, the ALB picks the next IP address on the list and sends the session there.


Each task, in turn, is like its own little pocket web server instance, standing by to receive and process user requests. Recall that each instance of our `arx-production-web-apps` task contains an Nginx process and a few different php-fpm processes:


[![Our currently running task list. Each task runs four ECS containers—Taberna for the front page store; Civis for the forum; Acta for the front page; and Nginx to reverse-proxy traffic to one of the three others.](https://cdn.arstechnica.net/wp-content/uploads/2023/07/running-tasks.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/07/running-tasks.jpg) / Our currently running task list. Each task runs four ECS containers—Taberna for the front page store; Civis for the forum; Acta for the front page; and Nginx to reverse-proxy traffic to one of the three others.


Inside those tasks, it's business as usual—things proceed mostly as they would in a “normal” server, though there are some complications. For one, we’ve left things in what seems to be somewhat of a fragmented mess—taking WordPress as the example we keep coming back to, don’t we now have multiple instances of the WordPress application all running in different states at different times on different hosts?


Well, sort of—but not in a way that matters. Let’s dig a little deeper.





## Contain yourself


As noted, each task is essentially a bundle of containers, and each container runs an application that, in turn, handles some aspect of site functionality. Here are our four standard containers again:


[![Our containers.](https://cdn.arstechnica.net/wp-content/uploads/2023/07/containers.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/07/containers.jpg) / Our containers.


If you were to ssh into those containers and look around, you’d be hard-pressed to differentiate them from any other Docker (or Docker-like) container. They each have a file system and some running processes, and they each work on part of the connection and then forward what they have to another host.


But that file system—where does it come from? And since it’s ephemeral, how do we keep track of changes? And since we have multiple tasks running, how do we ensure their changes don’t clobber each other?


File system first: The containers are all built with exactly the file system we want them to have, and that file system comes from the container base image. That container base image lives in a private GitHub repo, which we’ll explore more in part three:


[![We'll be going here in part three, so if GitHub is your jam, stand by!](https://cdn.arstechnica.net/wp-content/uploads/2023/07/github-repo.png)](https://cdn.arstechnica.net/wp-content/uploads/2023/07/github-repo.png) / We'll be going here in part three, so if GitHub is your jam, stand by!


As far as storing changes (like front page posts) and making sure the tasks’ changes are all processed in some kind of order, that's all relatively easy—we use the serverless Aurora MySQL database. The file system on each task contains endpoint information for the MySQL database in the form of a database host name, user name, and password; each task sends its database writes and reads to the Aurora MySQL service via that endpoint, and the database handles everything with appropriate [atomicity](https://en.wikipedia.org/wiki/Atomicity_(database_systems)). Plus, the database itself auto-scales up and down as needed, so we never need to care about it other than in terms of its monthly cost.


[![Our Aurora serverless database. There aren't really a lot of exposed knobs to fiddle with.](https://cdn.arstechnica.net/wp-content/uploads/2023/07/database.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/07/database.jpg) / Our Aurora serverless database. There aren't really a lot of exposed knobs to fiddle with.


The other thing for which we provide persistent storage to WordPress is user uploads—which for Ars tend to take the form of images embedded in stories. Now, what I’d like to do is point to the EFS section of the diagram and say that we’re providing our WordPress instance with persistent upload storage via EFS, but that isn’t quite the case yet—we’re leaning on another piece of AWS tech that predated EFS for persistent storage: [Simple Storage Service](https://aws.amazon.com/s3/), better known as S3.


“But Lee,” you say, “I didn’t see S3 in the functional block diagram you’ve been using!” Yes, I reply—like all functional diagrams, the one I posted is a mix of truth and aspiration. The truth part is that we’re leaning on S3 buckets to hold the collected uploads of our Ars authors. (Heck, we’re leaning on S3 for a bunch of stuff, including log repositories from other services and even our live-blogging engine—it’s super handy!)


Between the dev and test stuff, the logs, the live-blog archives, and the WordPress uploads, we’re sitting on about 7.8TB of data—which is maybe a lot, but maybe not, depending on your perspective. On the one hand, at my first storage administration job circa 2003, our entire site’s SAN was about 9TB total. On the other hand, that was 20 years ago, and these days you practically get a 10TB hard drive free with a tank of gas.


But coming back to the diagram and its truths and aspirations—the aspirational part is that we very much want to lessen our reliance on S3 and get *all* of our WordPress stuff moved over to EFS. S3 is great for infrequent access, but sticking a WordPress media library there can lead to some performance issues—especially when an Ars author is flipping through the media library trying to find an image. That’s more random access than S3 is comfortable regularly supporting.












## Tags:
***ipv4-adresses***: 10.1.0.0

### Autogenerated tags:
[[wordpress]] [[php]] [[s3]] [[php-fpm]] [[ip]] [[mysql]] [[nginx]] [[http]] [[arx-production-web-apps]] [[blog]]
