# Two core Unix-like utilities, sudo and su, are getting rewrites in Rust
## AWS-backed group believes command is too central to the web to keep as-is.
## Information:

+ Link: https://arstechnica.com/information-technology/2023/05/two-core-unix-like-utilities-sudo-and-su-are-getting-rewrites-in-rust/
+ Source: Ars Technica
+ Author: Kevin Purdy
+ Date published: 01 May 2023, 17:05
+ Date scraped: 01 May 2023, 18:01

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/05/GettyImages-958252348-760x380.jpg)







[![Invoking another user's privileges to <a href="https://xkcd.com/149/">execute a command</a>.](https://cdn.arstechnica.net/wp-content/uploads/2023/05/GettyImages-958252348-980x653.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/05/GettyImages-958252348-scaled.jpg) / Invoking another user's privileges to [execute a command](https://xkcd.com/149/).Cavan Images/Getty

Two of the most fundamental tools of the modern Unix-like command line, sudo and su, are being rewritten in the modern language Rust as part of a [wider effort](https://www.memorysafety.org/) to get critical but aging infrastructure pieces replaced by memory-safe counterparts.
As [detailed at Prossimo](https://www.memorysafety.org/blog/sudo-and-su/), a joint team from [Ferrous Systems](https://ferrous-systems.com/) and [Tweede Golf](https://tweedegolf.nl/), with support from Amazon Web Services, is reimplementing sudo and su. These utilities allow a user to perform actions with the privileges of another user (typically a higher-level superuser) without having to learn and enter that other user's password. Given their age and wide usage, the Prossimo team believes it's time for a rework.


"Sudo was first developed in the 1980s. Over the decades, it has become an essential tool for performing changes while minimizing risk to an operating system," writes Josh Aas. "But because it's written in C, sudo has experienced many vulnerabilities related to memory safety issues."


The sudo command fits the Prossimo projects criteria for reimplementation "squarely." It's used on nearly every server and client, it is on a critical boundary, it performs a critical function, and it is written in languages that are not memory-safe, like C and asm. The project's [work plan and milestones are posted](https://www.memorysafety.org/initiative/sudo-su/sudo-su-work-plan/), and you can [track the work on GitHub](https://github.com/memorysafety/sudo-rs).


Sudo was developed in 1980 by Robber Coggeshall and Cliff Spencer at the State University of New York at Buffalo (go Bulls) on [a VAX-11/750 running 4.1BSD](https://www.sudo.ws/about/history/). Coggeshall further developed sudo at the University of Colorado Boulder; the tool was eventually made public and maintained by Todd C. Miller. The su command was [part of Version 1 Unix](https://en.wikipedia.org/wiki/Su_(Unix)).


A well-funded effort to reimplement a core aspect of Unix-like systems, even in a well-regarded language like Rust, is all but guaranteed to [stir up the community](https://linux.slashdot.org/story/23/05/01/0020239/sudo-and-su-are-being-rewritten-in-rust-for-memory-safety). While it was developed over decades and is implemented in nearly every system, the sudo command is not without flaws. Certain versions of sudo were vulnerable to a [root-providing buffer-overflow bug](https://arstechnica.com/information-technology/2020/02/serious-flaw-that-lurked-in-sudo-for-9-years-finally-gets-a-patch/), as [reported in 2019](https://access.redhat.com/security/cve/cve-2019-14287). Then again, [the majority of sudo vulnerabilities](https://www.cvedetails.com/product/32625/Sudo-Project-Sudo.html?vendor_id=15714) do not appear memory-related (depending on one's definition); one can certainly code new bugs into software that's written in a memory-safe language.


The Prossimo group's milestones page does not explain how wider adoption of a Rust-based sudo and su would be promoted. It's a good bet that effort could require just as much effort as the rewrite itself.


*Listing image by Cavan Images/Getty*














## Tags:


### Autogenerated tags:
[[sudo]] [[prossimo]] [[memory-safe]]
