# Wazuh - The free and open source XDR platform
## Wazuh is a free and open source security platform that provides unified SIEM and XDR protection. It protects workloads across on-premises, virtualized, containerized, and cloud-based environments. Wazuh is one of the fastest growing open source security solutions, with over 10 million downloads per year.
## Information:

+ Link: https://www.bleepingcomputer.com/news/security/wazuh-the-free-and-open-source-xdr-platform/
+ Source: Bleeping Computer
+ Author: Bleeping Computer
+ Date published: 28 September 2022, 14:06
+ Date scraped: 28 September 2022, 16:03

## Article:
![Main article image](https://www.bleepstatic.com/content/hl-images/2022/09/27/wazuh-header-image.jpg)



Businesses need to be confident that their infrastructure is secure against digital threats. Poor data security can lead to data breaches and security incidents that negatively impact a business and its customers.


If cyberattacks are not promptly detected and mitigated, the aftermath can be expensive, time-consuming, and result in the loss of sensitive information.


Over time, cybercriminals have improved their techniques for evading basic security solutions. Therefore, businesses require a strong security plan.


The use of extended detection and response platforms (XDR) can improve an organization’s security posture.


An XDR is a platform that provides visibility, detection capabilities, and effective response to threats in an enterprise environment.


## Introducing Wazuh


Wazuh is a free and open source security platform that provides unified SIEM and XDR protection. It protects workloads across on-premises, virtualized, containerized, and cloud-based environments.


The Wazuh platform uses a server/agent model:


* Wazuh central components (server, indexer, and dashboard) that analyze security data collected from the agents. They can be set up on-premises or in the cloud using the [Wazuh Cloud](https://wazuh.com/cloud/?utm_source=bleepingcomputer.com&utm_medium=referral&utm_campaign=wazuh_bleepingcomputer) solution.
* Lightweight and universal security [agents](https://documentation.wazuh.com/current/installation-guide/wazuh-agent/index.html?utm_source=bleepingcomputer.com&utm_medium=referral&utm_campaign=wazuh_bleepingcomputer) are deployed on monitored endpoints to collect security data and perform automatic responses to threats.

The Wazuh solution also provides agentless monitoring for devices such as routers, firewalls, and switches that do not support the installation of agents.



![The Wazuh dashboard showing the summary of a Wazuh agent installed on an endpoint](https://www.bleepstatic.com/images/news/security/w/wazuh/open-source-xdr/wazuh-dashboard.png)**Fig. 1: The Wazuh dashboard showing the summary of a Wazuh agent installed on an endpoint**


In the following sections, we see some Wazuh capabilities that make it a comprehensive XDR.


### Endpoint security


Wazuh provides capabilities for threat prevention, detection, and response. The Wazuh agents installed on endpoints do the following:


* Collect security data.
* Report misconfigurations and security issues.
* Monitor file system and report changes.

In addition to security visibility and monitoring of endpoints, Wazuh provides self-defense capabilities and [automated responses](https://documentation.wazuh.com/current/user-manual/capabilities/active-response/?highlight=active%20response&utm_source=bleepingcomputer.com&utm_medium=referral&utm_campaign=wazuh_bleepingcomputer) to detected threats. The Wazuh solution can perform responsive actions like [removing malicious files](https://wazuh.com/blog/detecting-and-responding-to-malicious-files-using-cdb-lists-and-active-response/?utm_source=bleepingcomputer.com&utm_medium=referral&utm_campaign=wazuh_bleepingcomputer), [blocking malicious network connections](https://documentation.wazuh.com/current/user-manual/capabilities/active-response/ar-use-cases/blocking-attacks.html?utm_source=bleepingcomputer.com&utm_medium=referral&utm_campaign=wazuh_bleepingcomputer), and other countermeasures.


### Security Operations


An important feature of an XDR is its ability to aggregate, normalize, and correlate data from multiple sources. Wazuh collects large volumes of events across various devices and analyzes them to generate valuable security information.


The security agents have an [anomaly and malware detection](https://documentation.wazuh.com/current/user-manual/capabilities/anomalies-detection/index.html?utm_source=bleepingcomputer.com&utm_medium=referral&utm_campaign=wazuh_bleepingcomputer) module which detects abnormal and malicious events on endpoints.


Wazuh supports regulatory compliance by using rulesets that are carefully mapped against compliance requirements. Wazuh provides out-of-the-box support for compliance frameworks like PCI DSS, HIPAA, GDPR, NIST SP 800-53, and TSC.



![The Wazuh dashboard showing PCI DSS compliance information](https://www.bleepstatic.com/images/news/security/w/wazuh/open-source-xdr/wazuh-dashboard-pci-dss.png)**Fig. 2: The Wazuh dashboard showing PCI DSS compliance information**


### Threat Intelligence


Cybersecurity researchers and threat actors continue to find and exploit vulnerabilities in computer systems. It is, therefore, important for businesses to be aware of old and new vulnerabilities present in their IT infrastructure.


Wazuh has an inbuilt vulnerability detection module that periodically scans installed applications to find vulnerabilities. It correlates data received from the endpoints with up-to-date CVE (Common Vulnerabilities and Exposure) databases and provides security visibility.


The Wazuh solution also incorporates the MITRE ATT&CK framework to quickly recognize and hunt for adversary tactics, techniques, and procedures (TTPs) across an enterprise environment. Event alerts are mapped to their associated MITRE ATT&CK technique to include useful information.



![The Wazuh dashboard displaying MITRE ATT&CK information](https://www.bleepstatic.com/images/news/security/w/wazuh/open-source-xdr/wazuh-mitre.png)**Fig. 3: The Wazuh dashboard displaying MITRE ATT&CK information**


### Cloud Security


Businesses are increasingly relying on cloud-native solutions to host their services. Wazuh, in this regard, not only provides real-time protection for on-premises workloads but also for cloud infrastructure.


It can be integrated with cloud services like Google Cloud Platform (GCP), Amazon Web Services (AWS), and Microsoft Azure to provide cloud-level security to these infrastructures. Taking a step further, the Wazuh solution puts containerized workloads in mind by providing protection for popular technologies like Docker and Kubernetes.


### Free and Open Source


[Wazuh](https://wazuh.com/?utm_source=bleepingcomputer.com&utm_medium=referral&utm_campaign=wazuh_bleepingcomputer) is one of the fastest growing open source security solutions, with over 10 million downloads per year. Wazuh provides [communities](https://wazuh.com/community/?utm_source=bleepingcomputer.com&utm_medium=referral&utm_campaign=wazuh_bleepingcomputer) where users can engage Wazuh developers, share experiences, and ask questions related to the platform. 


Being free and open source provides an opportunity for scalability and customization. This platform can be easily [integrated](https://documentation.wazuh.com/current/user-manual/manager/manual-integration.html?highlight=integrator&utm_source=bleepingcomputer.com&utm_medium=referral&utm_campaign=wazuh_bleepingcomputer) with other open source tools and security solutions to enhance its XDR capabilities. Some of its integrations include VirusTotal, Suricata, YARA, and Slack, to name a few. Check out this [documentation](https://documentation.wazuh.com/current/quickstart.html?utm_source=bleepingcomputer.com&utm_medium=referral&utm_campaign=wazuh_bleepingcomputer) on how to get started with Wazuh.


*Sponsored by [Wazuh](https://wazuh.com/?utm_source=bleepingcomputer.com&utm_medium=referral&utm_campaign=wazuh_bleepingcomputer)*





## Tags:


### Autogenerated tags:
[[wazuh]] [[xdr]] [[cloud]] [[on-premises]] [[att&ck]]
