# Transforming SQL Queries Bypasses WAF Security
## A team of university researchers finds a machine learning-based approach to generating HTTP requests that slip past Web application firewalls.
## Information:

+ Link: https://www.darkreading.com/cloud/transforming-sql-queries-bypasses-waf-security
+ Source: DarkReading
+ Author: Robert Lemos
+ Date published: 12 May 2022, 23:20
+ Date scraped: 13 May 2022, 00:00

## Article:
![Main article image](https://eu-images.contentstack.com/v3/assets/blt66983808af36a8ef/blte0a314ea7bca841d/627d8d01d2ea9c6d8e572da9/SQL_sleepyfellow_AlamyStockPhoto.jpeg)

BLACK HAT ASIA 2022 — A team of university researchers used basic machine learning to identify patterns that common Web application firewalls (WAFs) fail to detect as malicious, but which can still deliver an attacker's payload, one of the researchers said in a presentation at the Black Hat Asia security conference in Singapore on Thursday.




The researchers from Zhejiang University in China started with common ways of transforming injection attacks to target Web-application databases using the common Structured Query Language (SQL). Rather than using a brute-force search of potential bypasses, the team created a tool, AutoSpear, that uses a pool of potential bypasses that can be combined using a weighted mutation strategy and then tested to determine the effectiveness of the bypasses at evading the security of WAF-as-a-service offerings. 


The tool successfully bypassed — as measured by a false negative rate — all seven of the tested cloud-based WAFs with a variety of success, from a low of 3% for ModSecurity to a high of 63% for Amazon Web Services' and Cloudflare's WAFs, said Zhenqing Qu, a Zhejiang University graduate student and member of the AutoSpear team.


"The case studies have shown the potential [of the tool], because detection signatures were not robust due to various vulnerabilities," he said. "Just adding comments or whitespace can bypass some WAFs, but the most effective mutation depends on specific WAFs."




Web application firewalls are a common way to defend important cloud software and Web services from attack, filtering out common application attacks and attempts at injecting database commands, also known as SQL injection (SQLi). A 2020 study, for example, found that 4 in 10 security professionals believed that [50% of application-layer attacks](https://www.darkreading.com/cloud/when-wafs-go-wrong) that targeted their cloud application bypassed their WAF. Other attacks focus on [compromising the WAF through its inspection of traffic](https://www.darkreading.com/vulnerabilities-threats/rapid7-discloses-zero-day-flaw-in-fortinet-s-fortiweb-waf-technology).


In [their presentation](https://www.blackhat.com/asia-22/briefings/schedule/index.html#autospear-towards-automatically-bypassing-and-inspecting-web-application-firewalls-25503), the team from Zhejiang University focused on ways of transforming requests using 10 different techniques for the four common request methods: POST and GET requests, either using JSON encoding or not. The researchers found that the four different types of requests were treated the same by four different WAF vendors, while others approached the inputs differently.


By systematically mutating the requests with different combinations of the 10 techniques — such as inline comments, substituting whitespace, and substituting the common tautologies (that is, "1=1") for others (such as, "2<3") — the researchers found a set of transformations that performed best against each of the seven different WAFs. 




"[C]ombining multiple mutation methods, AutoSpear is much more effective in bypassing mainstream WAF-as-a-service solutions due to their vulnerable detection signatures for semantic matching and regular expression matching," the researchers stated in their presentation slides.


SQL injection attacks continue to be a major risk for many companies. The OWASP Top-10 Web Security Risks rated the Injection class of vulnerabilities at the top of its list of risks in 2013 and 2017, and [as the No. 3 risk in 2021](https://www.darkreading.com/application-security/owasp-reshuffles-its-top-10-list-adds-new-categories). The list, released approximately every four years, uses more than 400 broad classes of weaknesses to determine the most significant threats for web applications. 


The research team started with creating Web applications that had specific vulnerabilities, and then used its approach to transforms the known exploits into a unique request that the WAF would not catch.


Bypassing Web application firewalls typically focus on three broad approaches. At the architectural level, attackers can find ways to circumvent the WAF and directly access the origin server. At the protocol level, a variety of techniques can use errors or mismatches in encoding assumptions, such as [HTTP request smuggling](https://www.darkreading.com/vulnerabilities-threats/researcher-details-vulnerabilities-found-in-aws-api-gateway), to bypass WAFs. Finally, at the payload level, attackers can use a variety of encoding transformation to fool the WAF into failing to detect an attack, while still producing a valid request from the standpoint of the database server.


The transformations allowed the attacks to be successful anywhere from 9% of the time to nearly 100% of the time, depending on the WAF and the request format, the team stated in their presentation. In one case, the researcher found that just adding a newline character, "/n", bypassed a major WAF-as-a-service.


**AWS, Cloudflare Affected**


The research team reported the vulnerabilities to all seven WAF providers: AWS, Cloudflare, CSC, F5, Fortinet, ModSecurity, and Wallarm. Cloudflare, F5, and Wallarm have fixed their issues, Zhenqing said. The team also provided the vendors with bypass patterns that can be used to detect the most common types of transformations.


"The other four are still working with us, since the flaws cannot be easily patched," he said.




## Tags:


### Autogenerated tags:
[[wafs]] [[cloudflare]] [[firewalls]] [[zhejiang]] [[sql]] [[autospear]] [[waf-as-a-service]]
