# AWS, Google, and Azure CLI Tools Could Leak Credentials in Build Logs
## Popular cloud CLI tools (AWS, Google Cloud, Azure) have a vulnerability ("LeakyCLI") exposing sensitive data in build logs.
## Information:

+ Link: https://thehackernews.com/2024/04/aws-google-and-azure-cli-tools-could.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 16 April 2024, 18:56
+ Date scraped: 16 April 2024, 14:10

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEgwQ61q1unaO9nkqOW0K1z3EHh_y570jaSgouXAlR1rG01KYF40mzLUX25xa6EKLgay3bswJMsLNB1v_5ew0M3wtjM0zAjJ1KPV2XDDcuwaGgP3k3ZwDs8XiUrg8uDsO9-V7oGsk6_zJixelpe-UtNY15ozlCZG6it-JdO6aA7WsOhNP_XzYLtq11GnbYls/s728-rw-e365/password.png)


New cybersecurity research has found that command-line interface (CLI) tools from Amazon Web Services (AWS) and Google Cloud can expose sensitive credentials in build logs, posing significant risks to organizations.


The vulnerability has been codenamed **LeakyCLI** by cloud security firm Orca.


"Some commands on Azure CLI, AWS CLI, and Google Cloud CLI can expose sensitive information in the form of environment variables, which can be collected by adversaries when published by tools such as GitHub Actions," security researcher Roi Nisimi [said](https://orca.security/resources/blog/leakycli-aws-google-cloud-command-line-tools-can-expose-sensitive-credentials-build-logs/) in a report shared with The Hacker News.


Microsoft has since [addressed](https://thehackernews.com/2023/11/alert-microsoft-releases-patch-updates.html) the issue as part of security updates released in November 2023, assigned it the CVE identifier CVE-2023-36052 (CVSS score: 8.6).


[![Cybersecurity](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiuUUskkMH9dUT3LF77_Q_irGuaE4LGjp-Am2Ls_UzGJ5EBnZHfuFiSvKs4OPE5KmfedBHcuZZVHS4Bh48UJx8brpwtg6Vr2Gepbaw-lGMIm9HjUhyphenhyphen2W5DVm5-ymwPS691Ie32TrCqFIv6SxNRA-jOKCKZrOB5dV7BfL0zVAhOO0neNkP9yv-XePBU1hN_0/s728-e365/wing-d.png)](https://thehackernews.uk/third-party-risk-management-saas)
The idea, in a nutshell, has to do with how the CLI commands such as could be used to show (pre-)defined environment variables and output to Continuous Integration and Continuous Deployment (CI/CD) logs. A list of such commands spanning AWS and Google Cloud is below 0


* aws lambda get-function-configuration
* aws lambda get-function
* aws lambda update-function-configuration
* aws lambda update-function-code
* aws lambda publish-version
* gcloud functions deploy <func> --set-env-vars
* gcloud functions deploy <func> --update-env-vars
* gcloud functions deploy <func> --remove-env-vars


Orca said it found several projects on GitHub that inadvertently leaked access tokens and other sensitive data via Github Actions, CircleCI, TravisCI, and Cloud Build logs.


[![Credentials in Build Logs](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjW9gEAIlkRudTrW3Uz_MgvD5JmBeprjX_tjDwfYQx_TUgyVtSX2RSd1PORM1l2vTcbIwJbe4yYBeQ9pLpp87sKsN_EVd7_hAppOm3v77iwj56uxeNonmmny-2TU5IxR_5sn3ThWHEIhc-MNEVFNrcfCjhppkOE-SoGBN_yfowHh66N5OfJT5pBD3HS36rH/s728-rw-e365/aws.png)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjW9gEAIlkRudTrW3Uz_MgvD5JmBeprjX_tjDwfYQx_TUgyVtSX2RSd1PORM1l2vTcbIwJbe4yYBeQ9pLpp87sKsN_EVd7_hAppOm3v77iwj56uxeNonmmny-2TU5IxR_5sn3ThWHEIhc-MNEVFNrcfCjhppkOE-SoGBN_yfowHh66N5OfJT5pBD3HS36rH/s728-rw-e365/aws.png)[![Credentials in Build Logs](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiPK6MTMcfktiRWR5je9VX0aByCy0eGEx7cPzegk7x0n_3Kc-Vs8jxutDPGMroc7WVIo5TCTOnEQHg9UyKhgg1iufI8zeUT1m5p18Azt0TeRiUu9m7mVg3iAmXahugYuHe1FxbMvAIW-4AzB58difid-vEqPXcIoxcFcs7QvDbOmejk2rnDuIvGVryrdXub/s728-rw-e365/github.png)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiPK6MTMcfktiRWR5je9VX0aByCy0eGEx7cPzegk7x0n_3Kc-Vs8jxutDPGMroc7WVIo5TCTOnEQHg9UyKhgg1iufI8zeUT1m5p18Azt0TeRiUu9m7mVg3iAmXahugYuHe1FxbMvAIW-4AzB58difid-vEqPXcIoxcFcs7QvDbOmejk2rnDuIvGVryrdXub/s728-rw-e365/github.png)
Unlike Microsoft, however, both Amazon and Google consider this to be expected behavior, requiring that organizations take steps to avoid storing secrets in environment variables and instead use a dedicated secrets store service like AWS Secrets Manager or Google Cloud Secret Manager.


[![Cybersecurity](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEj9LS2CMV85AM5f2fKKl2aPAnQ1iZEQKbHh7hRbW3rn3MowE5BXNOrNlHsrMYRMndplTjEmzciLAj6jVsDkRJI2IdSfFXSXuSlMn6gSgmzjKktBgyRTJsC-MayMQq8Z580Hjp8oCv0WoplbNRKlOEzR3RqajPwbLY2JzbQpwEIaW6u2UDkYmcWPO_Mmzq-X/s728-e365/cis-d.png)](https://thehackernews.uk/cis-controls-guide-sme)
Google also [recommends](https://cloud.google.com/sdk/gcloud#suppressing_prompting_writing_to_the_terminal_and_logging) the use of the "--no-user-output-enabled" option to suppress the printing of command output to standard output and standard error in the terminal.


"If bad actors get their hands on these environment variables, this could potentially lead to view sensitive information including credentials, such as passwords, user names, and keys, which could allow them to access any resources that the repository owners can," Nisimi said.


"CLI commands are by default assumed to be running in a secure environment, but coupled with CI/CD pipelines, they may pose a security threat."

 
  





## Tags:
***CVE's***: CVE-2023-36052

### Autogenerated tags:
[[aws]] [[google]] [[cloud]] [[github]] [[gcloud]] [[<func>]]
