# Apple Unveils PQ3 Protocol - Post-Quantum Encryption for iMessage
## Apple's iMessage is getting a major security boost with PQ3, the 'strongest' post-quantum encryption yet
## Information:

+ Link: https://thehackernews.com/2024/02/apple-unveils-pq3-protocol-post-quantum.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 22 February 2024, 21:55
+ Date scraped: 22 February 2024, 17:03

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiu4puJfO2DjDVSsbbpt6B5zBAw6fTc1GoO7Y93Iydwuf20PiQTq-7qUVG_gDwro0xwZE-GoJsZD1zqRusmZmfJo_ipnA88w98ACeuAQHq9ZRkqkHUfGwAwUfECdJufrd5TNHxg_oqiEp_0hZ02XNEf9YkY9Fwes8wFmgQXRFHFrOGyOgDRuFtaqJyHbaZH/s728-rw-e365/apple.jpg)


Apple has announced a new post-quantum cryptographic protocol called **PQ3** that it said will be integrated into iMessage to secure the messaging platform against future attacks arising from the threat of a practical quantum computer.


"With compromise-resilient encryption and extensive defenses against even highly sophisticated quantum attacks, PQ3 is the first messaging protocol to reach what we call Level 3 security — providing protocol protections that surpass those in all other widely deployed messaging apps," Apple [said](https://security.apple.com/blog/imessage-pq3/).


The iPhone maker described the protocol as "groundbreaking," "state-of-the-art," and as having the "strongest security properties" of any cryptographic protocol deployed at scale.


PQ3 is the latest security guardrail erected by Apple in iMessage after it switched from [RSA](https://en.wikipedia.org/wiki/RSA_(cryptosystem)) to Elliptic Curve cryptography ([ECC](https://blog.cloudflare.com/a-relatively-easy-to-understand-primer-on-elliptic-curve-cryptography)), and by protecting encryption keys on devices with the Secure Enclave in 2019.


While the current algorithms that underpin public-key cryptography (or asymmetric cryptography) are [based on mathematical problems](https://thehackernews.com/2022/08/single-core-cpu-cracked-post-quantum.html) that are easy to do in one direction but hard in reverse, a potential future breakthrough in quantum computing means classical mathematical problems deemed computationally intensive can be trivially solved, effectively threatening end-to-end encrypted (E2EE) communications.


The risk is compounded by the fact that threat actors could conduct what is known as a harvest now, decrypt later (HNDL) attack, wherein encrypted messages are stolen today in hopes of decoding them at a later point in time by means of a quantum computer once it becomes a reality.


In July 2022, the U.S. Department of Commerce's National Institute of Standards and Technology (NIST) chose [Kyber](https://thehackernews.com/2022/07/nist-announces-first-four-quantum.html) as the post-quantum cryptographic algorithm for general encryption. Over the last year, Amazon Web Services (AWS), Cloudflare, Google and Signal have [announced](https://thehackernews.com/2023/08/enhancing-tls-security-google-adds.html) [support](https://thehackernews.com/2023/09/signal-messenger-introduces-pqxdh.html) for quantum-resistant encryption in their products.


[![PQ3 Protocol](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjdkNxB8mtcdwj1lYGVbx14LQ8Y6uJqjDnYKIfzLUdPheQujLoR6CU1wkWTm_OU7i8i26J17WunVYvZ1Dov4tgqry1zVyuDN7Cui05g2V2ZSfZxDzeLJsfyz1WRVbQBUschW3j7bfYhOv-DhY4Gjg9KWekaw1_tFH4VDIw95Eaf1adwQ4t60SJDdWlh9p6z/s728-rw-e365/apple.jpg)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjdkNxB8mtcdwj1lYGVbx14LQ8Y6uJqjDnYKIfzLUdPheQujLoR6CU1wkWTm_OU7i8i26J17WunVYvZ1Dov4tgqry1zVyuDN7Cui05g2V2ZSfZxDzeLJsfyz1WRVbQBUschW3j7bfYhOv-DhY4Gjg9KWekaw1_tFH4VDIw95Eaf1adwQ4t60SJDdWlh9p6z/s728-rw-e365/apple.jpg)
Apple is the latest to join the post-quantum cryptography (PQC) bandwagon with PQ3, which combines Kyber and ECC and aims to achieve Level 3 security. In contrast, Signal, which introduced its own [PQXDH protocol](https://thehackernews.com/2023/09/signal-messenger-introduces-pqxdh.html), offers Level 2 security, which establishes a PQC key for encryption.


This refers to an approach where PQC is "used to secure both the initial key establishment and the ongoing message exchange, with the ability to rapidly and automatically restore the cryptographic security of a conversation even if a given key becomes compromised."


The protocol, per Apple, is also designed to mitigate the impact of key compromises by limiting how many past and future messages can be decrypted with a single compromised key. Specifically, its key rotation scheme guarantees that the keys are rotated every 50 messages at most and at least once every seven days.


Support for PQ3 is expected to start rolling out with the general availability of iOS 17.4, iPadOS 17.4, macOS 14.4, and watchOS 10.4 next month.


Cupertino's iMessage security upgrade follows the tech giant's [surprise decision](https://9to5mac.com/2023/11/16/apple-rcs-coming-to-iphone/) to bring Rich Communication Services (RCS) to its Messages app later this year, marking a much-needed shift from the [non-secure SMS standard](https://thehackernews.com/2023/08/new-android-14-security-feature-it.html).


It also said it will work towards improving the security and encryption of RCS messages. It's worth noting that while RCS does not implement E2EE by default, Google's Messages app for Android uses the [Signal Protocol](https://support.google.com/messages/answer/10262381) to secure RCS conversations.


While the adoption of advanced protections is always a welcome step, it remains to be seen if this is expanded beyond iMessage to include RCS messages.


  





## Tags:


### Autogenerated tags:
[[pq3]] [[rcs]] [[imessage]] [[post-quantum]] [[pqc]]
