# Cross-Regional Disaster Recovery with Elasticsearch
## Learn how Rewind used Elasticsearch in our cross-regional Disaster Recovery plan to strengthen the security and availability of our data
## Information:

+ Link: https://thehackernews.com/2022/04/cross-regional-disaster-recovery-with.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 13 April 2022, 02:50
+ Date scraped: 13 April 2022, 03:00

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEitL80zUEx6kf4-Ct4rdm9pZbZpIxWPUvi4bbasfPaAxYKwBwwgDBNOIGMrS-JxWnr1DAnzMQxnxEaG88WYMMPTqyN3-3XEqlTlMsEIaWKDwZwwmu-ov14HNytNVAXjel2vEprCLC7Gc6p9khxrGfvB22D2SV_0heTHAnSU9-ZDEncgpg37tkhfIzkH/s728-e1000/data.jpg)


Unsurprisingly, here at [Rewind](https://rewind.com/?utm_source=partner&utm_medium=Blogpost&utm_campaign=TheHackerNews_April2022), we've got a lot of data to protect (over 2 petabytes worth). One of the databases we use is called Elasticsearch (ES or Opensearch, as it is currently known in AWS). To put it simply, ES is a document database that facilitates lightning-fast search results. Speed is essential when customers are looking for a particular file or item that they need to restore using [Rewind](https://rewind.com/?utm_source=partner&utm_medium=Blogpost&utm_campaign=TheHackerNews_April2022). Every second of downtime counts, so our search results need to be fast, accurate, and reliable.


Another consideration was disaster [recovery](https://rewind.com/blog/data-recovery-services-essential-guide/). As part of our [System and Organization Controls Level 2 (SOC2)](https://rewind.com/blog/soc-2-rewind/) certification process, we needed to ensure we had a working disaster recovery plan to restore service in the unlikely event that the entire AWS region was down.


"An entire AWS region?? That will never happen!" (Except for [when it did](https://aws.amazon.com/message/12721/)) 


Anything is possible, things go wrong, and in order to meet our SOC2 requirements we needed to have a working solution. Specifically, what we needed was a way to replicate our customer's data securely, efficiently, and in a cost-effective manner to an alternate AWS region. The answer was to do what Rewind does so well - take a backup!


Let's dive into how Elasticsearch works, how we used it to securely backup data, and our current disaster recovery process.


## **Snapshots**


First, we'll need a quick vocabulary lesson. Backups in ES are called *snapshots*. Snapshots are stored in a *snapshot repository*. There are [multiple types of snapshot repositories](https://www.elastic.co/guide/en/elasticsearch/reference/current/snapshots-register-repository.html#ess-repo-types), including one backed by AWS S3. Since S3 has the ability to replicate its contents to a bucket in another region, it was a perfect solution for this particular problem.


AWS ES comes with an automated snapshot repository pre-enabled for you. The repository is configured by default to take hourly snapshots and you cannot change anything about it. This was a problem for us because we wanted a *daily* snapshot sent to a repository backed by one of our own S3 buckets, which was configured to replicate its contents to another region.


![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEhwJAIUxDaT3JdcAmTAWICwwWLLVBUBPcrfuFb0-5t9sQ3hw4vi4XQMQPKxR1nnF89qAM_WKasN3ZO_-uPWx6kfO5n6oGVRLhdhDpwlNMiU6O3mxoe4ZaUYH_wtPVnk4DCwwX3lg15RnvMk4FMsDKTDwt3T2dOoQzAy0eJ6IqsdlzoSEB6gsAt6J5wm/s728-e100/image-1.jpg)
Our only choice was to create and manage our own snapshot repository and snapshots.


Maintaining our own snapshot repository wasn't ideal, and sounded like a lot of unnecessary work. We didn't want to reinvent the wheel, so we searched for an existing tool that would do the heavy lifting for us. 


## **Snapshot Lifecycle Management (SLM)**


The first tool we tried was Elastic's [Snapshot lifecycle management (SLM)](https://www.elastic.co/guide/en/elasticsearch/reference/current/snapshots-take-snapshot.html#automate-snapshots-slm), a feature which is described as:


*The easiest way to regularly back up a cluster. An SLM policy automatically takes snapshots on a preset schedule. The policy can also delete snapshots based on retention rules you define.*


You can even use your own snapshot repository too. However, as soon as we tried to set this up in our domains it failed. We quickly learned that AWS ES is a modified version of Elastic. co's ES and that SLM was not supported in AWS ES.


#### **Curator**


The next tool we investigated is called [Elasticsearch Curator](https://github.com/elastic/curator). It was open-source and maintained by Elastic.co themselves. 


Curator is simply a Python tool that helps you manage your indices and snapshots. It even has helper methods for creating custom snapshot repositories which was an added bonus.


We decided to run Curator as a Lambda function driven by a scheduled EventBridge rule, all packaged in AWS SAM.


Here is what the final solution looks like:


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEhTj1jw-Un60N5q33JKUuaoQnckx_IDtCJgof1HhqyFYvTqoc5y7a9PrF8oJblyquZgOrcs0DbJqnOiVG2l7CisAfHLplbxj5WLkOcOK7SkWViHv93n1PKikXesrXU9ifbSQIFtnSpmea3J-wD_jJeF8N6Jzhn-6lPYh8OEPxxPojZaKPcEUiUNpH3y/s728-e100/image-2.jpg)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEhTj1jw-Un60N5q33JKUuaoQnckx_IDtCJgof1HhqyFYvTqoc5y7a9PrF8oJblyquZgOrcs0DbJqnOiVG2l7CisAfHLplbxj5WLkOcOK7SkWViHv93n1PKikXesrXU9ifbSQIFtnSpmea3J-wD_jJeF8N6Jzhn-6lPYh8OEPxxPojZaKPcEUiUNpH3y/s728-e100/image-2.jpg)
## **ES Snapshot Lambda Function**


The Lambda uses the Curator tool and is responsible for snapshot and repository management. Here's a diagram of the logic:


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEixKIRZafBBMOu9oqslgS-KR_7cSvdlXndjpxqyVT3QFD-cKKcrgZSBFSdyF6PP0JpSoYRynnhOjsGqpqIpr8w4OSNnKj0UGqbk8p-zUPNJxLzQ1NpMxO7dRi2l6JhDbkBvHW1b7PRUXiqkzNLOVsk2UdKQwaouSNrOQEo7W5EcjxDOOg9wAe4h2LLT/s728-e100/image-3.jpg)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEixKIRZafBBMOu9oqslgS-KR_7cSvdlXndjpxqyVT3QFD-cKKcrgZSBFSdyF6PP0JpSoYRynnhOjsGqpqIpr8w4OSNnKj0UGqbk8p-zUPNJxLzQ1NpMxO7dRi2l6JhDbkBvHW1b7PRUXiqkzNLOVsk2UdKQwaouSNrOQEo7W5EcjxDOOg9wAe4h2LLT/s728-e100/image-3.jpg)
As you can see above, it's a very simple solution. But, in order for it to work, we needed a couple things to exist:


* IAM roles to grant permissions
* An S3 bucket with replication to another region
* An Elasticsearch domain with indexes


## **IAM Roles**


The S3SnapshotsIAMRole grants *curator* the permissions needed for the creation of the snapshot repository and the management of actual snapshots themselves:


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEjOTdLNnJsZelD55_GpMe8UyuFKPLKjLqM8HjOtpTgLYW__25TY66etD6yVlS28eZiWZrYc45Z--oc28_vqgxqI4Pk4aYtc38QYNo4Dcono2DwmoVQ-DtgQ-42hmNnJuLX_1A1yQ-JUO_zTlQjJpwjMly9kRVU7t03ZD_NLnxG_Y-wl1m7-9qWNex7M/s728-e100/code-1.jpg)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEjOTdLNnJsZelD55_GpMe8UyuFKPLKjLqM8HjOtpTgLYW__25TY66etD6yVlS28eZiWZrYc45Z--oc28_vqgxqI4Pk4aYtc38QYNo4Dcono2DwmoVQ-DtgQ-42hmNnJuLX_1A1yQ-JUO_zTlQjJpwjMly9kRVU7t03ZD_NLnxG_Y-wl1m7-9qWNex7M/s728-e100/code-1.jpg)
The EsSnapshotIAMRole grants *Lambda* the permissions needed by curator to interact with the Elasticsearch domain:


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEiu2Ca63yYFfFNTX9gAF2TdZ7WI-Gr333s3N9see2x-2ZjSj9TPWGRbr45wKDwPNeeP3pK99WhT28WCfaEaBF8Wzirq8VjK-5yDm5EsSsPY-K8kmtFc0iS1-cHrv4RwuEjs5Wx9SbCcV-Uh1OmITph0MDLgRtdhSiq1KyhOx0gnCVjE5h23JLcg9GKA/s728-e100/code-2.jpg)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEiu2Ca63yYFfFNTX9gAF2TdZ7WI-Gr333s3N9see2x-2ZjSj9TPWGRbr45wKDwPNeeP3pK99WhT28WCfaEaBF8Wzirq8VjK-5yDm5EsSsPY-K8kmtFc0iS1-cHrv4RwuEjs5Wx9SbCcV-Uh1OmITph0MDLgRtdhSiq1KyhOx0gnCVjE5h23JLcg9GKA/s728-e100/code-2.jpg)
## **Replicated S3 Buckets**


The team had previously set up replicated S3 buckets for other services in order to facilitate cross region replication in Terraform. (More info on that [here](https://docs.aws.amazon.com/AmazonS3/latest/userguide/replication.html)) 


With everything in place, the cloudformation stack deployed in production initial testing went well and we were done…or were we?


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEjmZ4vFCFvp9_0gQ5OO1sT7NRbI633xHubvKjK8DJJ682ZpW3szzRCSYmdZ6NJZRIrFvJw7694Yj6YLHizQ2GObk3oXP5LXfJRW5cGqZv2ZvJRa78pqI67Ei2fJTLd6qHdqJqkWXRJoF3iNmiOBtfZwXiaOqUgmfJUnxPaJvNqR2QRv87CcjETfpeLI/s728-e100/image-7.jpg)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEjmZ4vFCFvp9_0gQ5OO1sT7NRbI633xHubvKjK8DJJ682ZpW3szzRCSYmdZ6NJZRIrFvJw7694Yj6YLHizQ2GObk3oXP5LXfJRW5cGqZv2ZvJRa78pqI67Ei2fJTLd6qHdqJqkWXRJoF3iNmiOBtfZwXiaOqUgmfJUnxPaJvNqR2QRv87CcjETfpeLI/s728-e100/image-7.jpg)
#### **Backup and Restore-a-thon I**


Part of SOC2 certification requires that you validate your production database backups for all critical services. Because we like to have some fun, we decided to hold a quarterly "Backup and Restore-a-thon". We would assume the original region was gone and that we had to restore each database from our cross regional replica and validate the contents.


One might think "Oh my, that is a lot of unnecessary work!" and you would be half right. It is a lot of work, but it is absolutely necessary! In each Restore-a-thon we have uncovered at least one issue with services not having backups enabled, not knowing how to restore, or access the restored backup. Not to mention the hands-on training and experience team members gain actually doing something not under the high pressure of a real outage. Like running a fire drill, our quarterly Restore-a-thons help keep our team prepped and ready to handle any emergency.


The first ES Restore-a-thon took place months after the feature was complete and deployed in production so there were many snapshots taken and many old ones deleted. We configured the tool to keep 5 days worth of snapshots and delete everything else.


Any attempts to restore a replicated snapshot from our repository failed with an unknown error and not much else to go on.


Snapshots in ES are incremental meaning the higher the frequency of snapshots the faster they complete and the smaller they are in size. The initial snapshot for our largest domain took over 1.5 hours to complete and all subsequent daily snapshots took minutes!


This observation led us to try and protect the initial snapshot and prevent it from being deleted by using a name suffix (-initial) for the very first snapshot taken after repository creation. That initial snapshot name is then excluded from the snapshot deletion process by Curator using a regex filter.


We purged the S3 buckets, snapshots, and repositories and started again. After waiting a couple of weeks for snapshots to accumulate, the restore failed again with the same cryptic error. However, this time we noticed the initial snapshot (that we protected) was also missing! 


With no cycles left to spend on the issue, we had to park it to work on other cool and awesome things that we work on here at [Rewind](https://rewind.com/?utm_source=partner&utm_medium=Blogpost&utm_campaign=TheHackerNews_April2022).


#### **Backup and Restore-a-thon II**


Before you know it, the next quarter starts and it is time for another Backup and Restore-a-thon and we realize that this is still a gap in our disaster recovery plan. We need to be able to restore the ES data in another region successfully. 


We decided to add extra logging to the Lambda and check the execution logs daily. Days 1 to 6 are working perfectly fine - restores work, we can list out all the snapshots, and the initial one is still there. On the 7th day something strange happened - the call to list the available snapshots returned a "not found" error for only the initial snapshot. What external force is deleting our snapshots??


We decided to take a closer look at the S3 bucket contents and see that it is all UUIDs (Universally Unique Identifier) with some objects correlating back snapshots except for the initial snapshot which was missing. 


We noticed the "show versions" toggle switch in the console and thought it was odd that the bucket had versioning enabled on it. We enabled the version toggle and immediately saw "Delete Markers" all over the place including one on the initial snapshot that corrupted the entire snapshot set. 


Before & After


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEisSVz6vbggouiMG0F9ruPv_fEaMbl_dYH_gcHsfIf9816GniEgJXF4DfVypkeiUORm9s5cg32Fbf2nGu9dmOZFTYKq8Hdoqu3Aa4KpzAgdOuEYZ0E8NOXnJKgo9cdXsBGZS178vG_Genjwqmz4x3uOPtZOyJ1lhq8YlbhoRyvKOR8eItazVVjbgirN/s728-e100/before.jpg)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEisSVz6vbggouiMG0F9ruPv_fEaMbl_dYH_gcHsfIf9816GniEgJXF4DfVypkeiUORm9s5cg32Fbf2nGu9dmOZFTYKq8Hdoqu3Aa4KpzAgdOuEYZ0E8NOXnJKgo9cdXsBGZS178vG_Genjwqmz4x3uOPtZOyJ1lhq8YlbhoRyvKOR8eItazVVjbgirN/s728-e100/before.jpg)
We very quickly realized that the S3 bucket we were using had a 7 day lifecycle rule that purged all objects older than 7 days. 


The lifecycle rule exists so that unmanaged objects in the buckets are automatically purged in order to keep costs down and the bucket tidy.


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgB18Yyf7rG-QaKvxXL1yGcKixK9mHntE2CfaJi52DYSWOv-h0vEgcqOS97huzgyGYhxGFZcz6Pt23YOkWgaKBTpSsv1_zvxXLPOWXjh9I17dGrmZVPoOPldZwc3kkzOtpuhBfkY6aheizHyttng1iOc1CZSm8GtpnXuLlMHn0GM-PkIOIrrpzWQU0f/s728-e100/image-5.jpg)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgB18Yyf7rG-QaKvxXL1yGcKixK9mHntE2CfaJi52DYSWOv-h0vEgcqOS97huzgyGYhxGFZcz6Pt23YOkWgaKBTpSsv1_zvxXLPOWXjh9I17dGrmZVPoOPldZwc3kkzOtpuhBfkY6aheizHyttng1iOc1CZSm8GtpnXuLlMHn0GM-PkIOIrrpzWQU0f/s728-e100/image-5.jpg)
We restored the deleted object and voila, the listing of snapshots worked fine. Most importantly, the restore was a success.


## **The Home Stretch**


In our case, Curator must manage the snapshot lifecycle so all we needed to do was prevent the lifecycle rule from removing anything in our snapshot repositories using a scoped path filter on the rule.


We created a specific S3 prefix called "/auto-purge" that the rule was scoped to. Everything older than 7 days in /auto-purge would be deleted and everything else in the bucket would be left alone.


We cleaned up everything once again, waited > 7 days, re-ran the restore using the replicated snapshots, and finally it worked flawlessly - Backup and Restore-a-thon finally completed!


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgOkhLBbgdqPWmb4oDzWq6vDBgQp1N43AhXfROC2fvXIpvCrtlAKdfXdbQce7hXCb80sRNLvNTIi4UouxUYZCUNer6Z9KvQoupCUOKT-z2ZAVhmXAbLSQ9ile6IyD3SUqWLD5UyFOHd9PK1CKto5Yu5I1tGL7l2vrmIlyGmAVKZcUglLipkqRPzvLx7/s728-e100/image-6.jpg)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgOkhLBbgdqPWmb4oDzWq6vDBgQp1N43AhXfROC2fvXIpvCrtlAKdfXdbQce7hXCb80sRNLvNTIi4UouxUYZCUNer6Z9KvQoupCUOKT-z2ZAVhmXAbLSQ9ile6IyD3SUqWLD5UyFOHd9PK1CKto5Yu5I1tGL7l2vrmIlyGmAVKZcUglLipkqRPzvLx7/s728-e100/image-6.jpg)
## **Conclusion**


Coming up with a disaster recovery plan is a tough mental exercise. Implementing and testing each part of it is even harder, however it's an essential business practice that ensures your organization will be able to weather any storm. Sure, a house fire is an unlikely occurrence, but if it does happen, you'll probably be glad you practiced what to do before smoke starts billowing. 


Ensuring business continuity in the event of a provider outage for the critical parts of your infrastructure presents new challenges but it also provides amazing opportunities to explore solutions like the one presented here. Hopefully, our little adventure here helps you avoid the pitfalls we faced in coming up with your own Elasticsearch disaster recovery plan.

***Note —** This article is written and contributed by Mandeep Khinda, DevOps Specialist at Rewind.*


  





## Tags:


### Autogenerated tags:
[[s3]] [[aws]] [[restore-a-thon]] [[elasticsearch]] [[lifecycle]] [[slm]] [[soc2]]
