# GitHub's Secret Scanning Feature Now Covers AWS, Microsoft, Google, and Slack
## GitHub's secret scanning just got even better! Now supporting AWS, Microsoft, Google, and Slack tokens, ensuring your code's safety.
## Information:

+ Link: https://thehackernews.com/2023/10/githubs-secret-scanning-feature-now.html
+ Source: The Hacker News
+ Author: Newsroom
+ Date published: 06 October 2023, 14:23
+ Date scraped: 06 October 2023, 09:01

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjT8DW77NxmX7RajR0-RxXmAbfxlS3qqh2LhDfRBNb9sBK9gUWHTk_B2Pu06i_dleZBWDEydKFpbGsw-Dd-JKYDMzHyks4mhVNtlENlpDDB2ybGx_Ad33oBUVaIUXcYuBufi3tI79cSx-ENUMCSVTc84bPGL9lDfcXTQDxQ0VIZDv2VMe6ERIaCoW5ezThr/s728-rw-ft-e30/github-secret.jpg)


GitHub has [announced](https://github.blog/2023-10-04-introducing-secret-scanning-validity-checks-for-major-cloud-services/) an improvement to its secret scanning feature that extends validity checks to popular services such as Amazon Web Services (AWS), Microsoft, Google, and Slack.


Validity checks, [introduced](https://github.blog/2023-01-19-remediation-made-simple-introducing-new-validity-checks-for-github-tokens/) by the Microsoft subsidiary earlier this year, alert users whether exposed tokens found by [secret scanning](https://thehackernews.com/2022/12/github-announces-free-secret-scanning.html) are active, thereby allowing for effective remediation measures. It was first enabled for GitHub tokens.


The cloud-based code hosting and version control service said it intends to support more tokens in the future.


To toggle the setting, enterprise or organization owners and repository administrators can head to Settings > Code security and analysis > Secret scanning and check the option "Automatically verify if a secret is valid by sending it to the relevant partner."


Earlier this year, GitHub also [expanded](https://github.blog/2023-02-28-secret-scanning-alerts-are-now-available-and-free-for-all-public-repositories/) secret scanning alerts for all public repositories and announced the [availability of push protection](https://thehackernews.com/2023/05/github-extends-push-protection-to.html) to help developers and maintainers proactively secure their code by scanning for highly identifiable secrets before they are pushed.


The development comes as Amazon previewed enhanced account protection requirements that will enforce privileged users (aka root users) of an [AWS Organization](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_introduction.html) account to switch on multi-factor authentication (MFA) starting in mid-2024.


"MFA is one of the simplest and most effective ways to enhance account security, offering an additional layer of protection to help prevent unauthorized individuals from gaining access to systems or data," Steve Schmidt, chief security officer at Amazon, [said](https://aws.amazon.com/blogs/security/security-by-design-aws-to-enhance-mfa-requirements-in-2024/).


Weak or misconfigured MFA methods also found a place among the top 10 most common network misconfigurations, according to a new [joint advisory](https://www.cisa.gov/news-events/news/joint-advisory-top-cyber-misconfigurations-highlights-urgency-software-manufacturers-incorporate) issued by the U.S. National Security Agency (NSA) and Cybersecurity and Infrastructure Security Agency (CISA).


[![GitHub](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEi4Io-_-Kdn-Vj52VKWjGiB0dcVxHI2ZuxN4Q0O4G0x4NHFCBmakHdm1hOtn-sHexp_TjJASPkm6YAv3RrxDzrZfWl6Y1kF2vSvDrLOrFcN7bg8-zmg702qJvIbZc_v96517yC4vyP3kwUVv3o4kCxzzWXIEsYAFkCohS95piP_R5ZiqiABtQn3vyIrUjTc/s728-rw-ft-e30/git.gif)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEi4Io-_-Kdn-Vj52VKWjGiB0dcVxHI2ZuxN4Q0O4G0x4NHFCBmakHdm1hOtn-sHexp_TjJASPkm6YAv3RrxDzrZfWl6Y1kF2vSvDrLOrFcN7bg8-zmg702qJvIbZc_v96517yC4vyP3kwUVv3o4kCxzzWXIEsYAFkCohS95piP_R5ZiqiABtQn3vyIrUjTc/s728-rw-ft-e30/git.gif)
"Some forms of MFA are vulnerable to phishing, 'push bombing,' exploitation of Signaling System 7 ([SS7](https://en.wikipedia.org/wiki/Signalling_System_No._7)) protocol vulnerabilities, and/or 'SIM swap' techniques," the agencies [said](https://www.cisa.gov/news-events/cybersecurity-advisories/aa23-278a).


"These attempts, if successful, may allow a threat actor to gain access to MFA authentication credentials or bypass MFA and access the MFA-protected systems."


The other prevalent cybersecurity misconfigurations are as follows -


* Default configurations of software and applications
* Improper separation of user/administrator privilege
* Insufficient internal network monitoring
* Lack of network segmentation
* Poor patch management
* Bypass of system access controls
* Insufficient access control lists (ACLs) on network shares and services
* Poor credential hygiene
* Unrestricted code execution


As mitigations, it's recommended that organizations eliminate default credentials and harden configurations; disable unused services and implement access controls; prioritize patching; audit and monitor administrative accounts and privileges.


Software vendors have also been urged to implement secure by design principles, use memory-safe programming languages where possible, avoid embedding default passwords, [provide high-quality audit logs](https://thehackernews.com/2023/07/microsoft-expands-cloud-logging-to.html) to customers at no extra charge, and mandate phishing-resistant MFA methods.


"These misconfigurations illustrate (1) a trend of systemic weaknesses in many large organizations, including those with mature cyber postures, and (2) the importance of software manufacturers embracing secure-by-design principles to reduce the burden on network defenders," the agencies noted.


  





## Tags:


### Autogenerated tags:
[[mfa]] [[github]] [[misconfigurations]]
