# In the jungle of AWS S3 Enumeration
## Navigating the complexities of AWS S3 Enumeration is crucial for securing misconfigured S3 buckets, which are potential gateways to sensitive data exposure.
## Information:

+ Link: https://hackread.com/in-the-jungle-of-aws-s3-enumeration/
+ Source: HACKRead
+ Author: Daily Contributors
+ Date published: 31 May 2024, 00:46
+ Date scraped: 31 May 2024, 00:06

## Article:
![Main article image](https://hackread.com/wp-content/uploads/2024/05/in-the-jungle-of-aws-s3-enumeration.jpg)


Amazon Web Services (AWS) Simple Storage Service (S3) is a foundational pillar of cloud storage, offering scalable object storage for millions of applications. However, [misconfigured S3 buckets](https://hackread.com/misconfigured-aws-bucket-artwork-archive-data/) can be a gateway to sensitive data exposure.


In this guide, we will delve into advanced methods for S3 bucket reconnaissance — essential for cloud pentesters and cloud security experts to identify and secure vulnerable buckets before they’re exploited.






### **The Current Situation**


In the cloud monitoring service Datadog’s [article](https://www.datadoghq.com/state-of-aws-security/) on the state of security in AWS, they analyzed trends in the implementation of security best practices and took a closer look at various types of…



![](https://hackread.com/wp-content/uploads/2024/05/image-10.png)

Credit: DatadogHQ




**36% of organizations with at least one Amazon S3 bucket have it configured to be publicly readable**. This is a significant cybersecurity risk, as publicly accessible S3 buckets can expose sensitive data to unauthorized individuals, leading to potential data breaches, data theft, and a host of compliance issues.


We could model the attack from a high-level point of view as follows:



![](https://hackread.com/wp-content/uploads/2024/05/image-11.png)

Classical S3 Attack Path Scenario




In this article, we will focus on the recognition techniques used by attackers in part 1 of the figure above.


### **Google Dorking to Locate Buckets**


[Google Dorking](https://en.wikipedia.org/wiki/Google_hacking) utilizes advanced search queries to find hidden information on the internet. When it comes to S3 buckets, specific dorks can reveal buckets left exposed by inadvertent configurations.


Example Commands:



![](https://hackread.com/wp-content/uploads/2024/05/image-14.png)


First command result example:



![](https://hackread.com/wp-content/uploads/2024/05/image-15.png)


Search results will list web pages or direct links to S3 buckets. Verify the legitimacy of each link, as some may be outdated or reference non-existent buckets. For actual buckets, proceed to check the permissions and contents, ideally reporting any misconfigurations to the bucket owner.


### **Burp Suite Exploration**


Burp Suite is a powerful tool for web application security pentesting. It can be used for S3 bucket reconnaissance by monitoring HTTP requests that contain bucket information.


Configure your browser to use Burp Suite as its proxy, then browse the target application. Burp Suite will automatically capture the traffic. Analyze the sitemap generated by Burp for any S3 bucket links or headers.


Look for patterns such as:


* URLs containing “s3.amazonaws.com”
* Headers with “x-am-bucket”






For instance:



![](https://hackread.com/wp-content/uploads/2024/05/image-16.png)

Burp s3 keyword search through the proxy history




Also, the Burp plugin [AWS Security Checks](https://github.com/portswigger/aws-security-checks) from the BApp Store can be really useful. The traffic analysis capabilities of Burp Suite allow for detailed scrutiny of web applications and potential S3 bucket discovery inside indirect or sub calls.


### **GitHub Recon Tools**


There’s a treasure trove of S3 reconnaissance tools on GitHub. These tools range in functionality from scanning bucket names to checking for public accessibility and dumping contents.



```
S3Scanner: https://github.com/sa7mon/S3Scanner  
  
Dumpster Diver: https://github.com/securing/DumpsterDiver  
  
S3 Bucket Finder: https://github.com/gwen001/s3-buckets-finder  
  
AWSInventorySync: https://github.com/foreseon/AWSInventorySync
```

Leveraging automated tools can vastly increase the efficiency and breadth of your reconnaissance. After running these tools, the next steps should involve assessing the identified buckets’ configurations, understanding the potential risks, and, if necessary, alerting the responsible parties.


### **Online Websites**


Online resources can streamline the S3 bucket discovery process. Nuclei templates, specifically, are predefined patterns used to detect common vulnerabilities, including [misconfigured S3 buckets](https://hackread.com/350-million-email-addresses-misconfigured-aws-s3-bucket/).


For instance you can use:


* [Osint.sh/buckets](https://osint.sh/buckets)
* [Buckets.grayhatwarfare](https://buckets.grayhatwarfare.com)


Tools like OSINT.sh and GrayHatWarfare are tailor-made to simplify the search process, pulling from pools of data that might take an individual researcher considerable time to amass.


What’s more, the existence of SaaS services accessible with just three clicks shows just how widespread this attack is these days. Hackers have even developed automated programs for scanning and collecting objects publicly exposed in S3 buckets.


### **Regex Mastery**


Mastering simple regex can be one of the most efficient ways to conduct S3 bucket reconnaissance. By chaining simple commands, you can create powerful searches.


### **Running Commands**


Here’s how to use regex with curl to extract S3 bucket URLs from JavaScript files:



![](https://hackread.com/wp-content/uploads/2024/05/image-12.png)


And for using subfinder and httpx:



![](https://hackread.com/wp-content/uploads/2024/05/image-13.png)


The command-line outputs will typically provide you with raw URLs or status codes. A 200 status code on an S3 bucket URL, for example, indicates that the bucket is accessible.


Further exploration of these command-line techniques offers granular control over the reconnaissance process and can be customized for specific scenarios. The output from these commands must be carefully analyzed to distinguish between normal bucket usage and potential security risks.






### **Conclusion**


Navigating the complexities of AWS S3 Enumeration is crucial for identifying and securing misconfigured S3 buckets, which are potential gateways to sensitive data exposure.


Identifying these vulnerabilities is only the first step. Action must be taken to mitigate these risks, ensuring data remains secure against potential breaches. This is where Resonance Security steps in.



> Specializing in cloud security audits and penetration testing, we provide the expertise needed to protect and reinforce cloud environments against threats.
> 
> 
>  Resonance Security


For companies looking to enhance their cloud security posture, we offer tailored pentests & audits designed to meet the unique challenges of securing your cloud infrastructure. Learn more about how we can support your cloud security needs at [Resonance Security](https://resonance.security/).


In sum, the path to secure AWS S3 storage is multifaceted, demanding a proactive approach to security. With the right techniques and expert support, companies can navigate this landscape confidently, protecting their most valuable digital assets.



[![Ilan Abitbol](https://hackread.com/wp-content/uploads/2024/05/Ilan-Abitbol-1024x895.jpg)](https://hackread.com/wp-content/uploads/2024/05/Ilan-Abitbol.jpg)



**As a Lead Security Engineer at Resonance Security, I play a pivotal role in shaping our cybersecurity landscape.**





## Tags:
***urls***: https://github.com/gwen001/s3-buckets-finderAWSInventorySync https://github.com/securing/DumpsterDiverS3 https://github.com/sa7mon/S3ScannerDumpster https://github.com/foreseon/AWSInventorySync

### Autogenerated tags:
[[s3]] [[cloud]] [[aws]] [[misconfigured]] [[urls]] [[regex]]
