# Organizations Respond to HTTP/2 Zero-Day Exploited for DDoS Attacks
## Organizations respond to HTTP/2 Rapid Reset zero-day vulnerability exploited to launch the largest DDoS attacks seen to date.
## Information:

+ Link: https://www.securityweek.com/organizations-respond-to-http-2-zero-day-exploited-for-ddos-attacks/
+ Source: SecurityWeek
+ Author: Eduard Kovacs
+ Date published: 11 October 2023, 11:07
+ Date scraped: 11 October 2023, 12:00

## Article:
![Main article image](https://www.securityweek.com/wp-content/uploads/2023/10/HTTP2-Rapid-Reset.png)


**Major tech companies and other organizations have rushed to respond to the newly disclosed HTTP/2 zero-day vulnerability that has been exploited to launch the largest distributed denial-of-service (DDoS) attacks seen to date.**


The existence of the attack method, named [HTTP/2 Rapid Reset](https://www.securityweek.com/rapid-reset-zero-day-exploited-to-launch-largest-ddos-attacks-in-history/), and the underlying vulnerability, tracked as CVE-2023-44487, were disclosed on Tuesday by [Cloudflare](https://blog.cloudflare.com/technical-breakdown-http2-rapid-reset-ddos-attack/), [AWS](https://aws.amazon.com/blogs/security/how-aws-protects-customers-from-ddos-events/) and [Google](https://cloud.google.com/blog/products/identity-security/how-it-works-the-novel-http2-rapid-reset-ddos-attack).


Each of the tech giants saw DDoS attacks aimed at customers peaking at hundreds of millions of requests per second, far more than they had previously seen. One noteworthy aspect is that the attacks came from relatively small botnets powered by just tens of thousands of devices.

While their existing DDoS protections were largely able to block the attacks, Google, Cloudflare and AWS implemented additional mitigations for this specific attack vector. In addition, they notified web server software companies, which have started working on patches.

The new attack method abuses an HTTP/2 feature called ‘stream cancellation’. Attackers repeatedly send a request and immediately cancel it, which results in a DoS condition capable of taking down servers and applications running standard HTTP/2 implementations.

Several organizations have published blog posts, advisories and alerts on Tuesday in response to the HTTP/2 Rapid Reset vulnerability.

**CISA**


The US cybersecurity agency [CISA](https://www.cisa.gov/news-events/alerts/2023/10/10/http2-rapid-reset-vulnerability-cve-2023-44487) has released an alert to warn organizations about the threat posed by HTTP/2 Rapid Reset, providing links to various useful resources, including its own guidance for mitigating DDoS attacks.


**Microsoft**


[Microsoft](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2023-44487) published an advisory to inform customers that it’s aware of the HTTP/2 Rapid Reset attack. The tech giant has advised users to install the available web server updates and provided a couple of workarounds that involve disabling the HTTP/2 protocol using the Registry Editor, and limiting applications to HTTP1.1 using protocol settings for each Kestral endpoint. 


**NGINX**


[NGINX](https://www.nginx.com/blog/http-2-rapid-reset-attack-impacting-f5-nginx-products/) warned that the HTTP/2 Rapid Reset vulnerability can — under certain conditions — be exploited to launch a DoS attack on NGINX Open Source, NGINX Plus, and related products that implement the server-side portion of the HTTP/2 specification. Users have been advised to immediately update their NGINX configuration.


**OpenSSF**


The Open Source Security Foundation ([OpenSSF](https://openssf.org/blog/2023/10/10/http-2-rapid-reset-vulnerability-highlights-need-for-rapid-response/)) has published a blog post calling attention to the underlying vulnerability, pointing out that the issue highlights the need for rapid response. 


**F5**


[F5](https://my.f5.com/manage/s/article/K000137106) said the vulnerability allows a remote, unauthenticated attacker to cause an increase in CPU usage that can lead to a DoS condition on BIG-IP systems. The company’s advisory contains a list of affected products and mitigations. 


**Netty**


Developers of [Netty](https://netty.io/news/2023/10/10/4-1-100-Final.html), a framework designed for the development of network applications such as protocol servers and clients, announced the release of version 4.1.100.Final, which fixes the HTTP/2 DDoS attack vector.


**Apache**


[Apache Tomcat](https://tomcat.apache.org/security-10.html#Fixed_in_Apache_Tomcat_10.1.14) developers have confirmed that Tomcat’s HTTP/2 implementation is vulnerable to the Rapid Reset attack. Apache Tomcat 10.1.14 fixes CVE-2023-44487.


**Swift**


[Swift](https://forums.swift.org/t/swift-nio-http2-security-update-cve-2023-44487-http-2-dos/67764), the programming language for Apple applications, has informed users that if they run a publicly accessible HTTP/2 server using ‘swift-nio-http2’ they should immediately update to version 1.28.0.


**Linux distributions**


Linux distributions such as [Red Hat](https://access.redhat.com/security/cve/cve-2023-44487), [Ubuntu](https://ubuntu.com/security/CVE-2023-44487) and [Debian](https://www.debian.org/security/2023/dsa-5522) have also published advisories for CVE-2023-44487. 


**Related**: [CISA Releases Guidance on Adopting DDoS Mitigations](https://www.securityweek.com/cisa-releases-guidance-on-adopting-ddos-mitigations/)


**Related**: [Canadian Government Targeted With DDoS Attacks by Pro-Russia Group](https://www.securityweek.com/canadian-government-targeted-with-ddos-attacks-by-pro-russia-group/)


**Related**: [After Microsoft and X, Hackers Launch DDoS Attack on Telegram](https://www.securityweek.com/after-microsoft-and-x-hackers-launch-ddos-attack-on-telegram/)





## Tags:
***CVE's***: CVE-2023-44487

### Autogenerated tags:
[[http/2]] [[ddos]] [[nginx]] [[cve-2023-44487]] [[mitigations]] [[microsoft]]
