# AWS Patches Critical 'FlowFixation' Bug in Airflow Service to Prevent Session Hijacking
## A now-patched vulnerability in AWS Managed Workflows for Apache Airflow (MWAA) could have allowed attackers to hijack sessions & execute code remotely
## Information:

+ Link: https://thehackernews.com/2024/03/aws-patches-critical-flowfixation-bug.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 22 March 2024, 19:15
+ Date scraped: 22 March 2024, 14:04

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEilrCQsxfYxjv4mQlWwoB9t1FgUiTOj-bS5DR7xS8YcY9RuVxteldI4VqiFFZGmkR084xmwFsifB8HUcTI5s25Xg4E0NpY9AsOGzOC4tyWLDziLxt4T09T3lMLi8MTxn_9YF5pM63YhcpATiT6Z2caLEy9wdCLmQ3W2R1Iad2psPKFcIV8K1P2oCEyW58mD/s728-rw-e365/aws.jpg)


Cybersecurity researchers have shared details of a now-patched security vulnerability in Amazon Web Services (AWS) Managed Workflows for Apache Airflow ([MWAA](https://docs.aws.amazon.com/mwaa/latest/userguide/what-is-mwaa.html)) that could be potentially exploited by a malicious actor to hijack victims' sessions and achieve remote code execution on underlying instances.


The vulnerability, now addressed by AWS, has been codenamed **FlowFixation** by Tenable.


"Upon taking over the victim's account, the attacker could have performed tasks such as reading connection strings, adding configurations and triggering directed acyclic graphs (DAGS)," senior security researcher Liv Matan [said](https://www.tenable.com/blog/flowfixation-aws-apache-airflow-service-takeover-vulnerability-and-why-neglecting-guardrails) in a technical analysis.


"Under certain circumstances such actions can result in RCE on the instance that underlies the MWAA, and in lateral movement to other services."


[![Cybersecurity](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhdKpsEk81OwnOikxTKgpp0fKbGZ8sQlNdSutORGiIEXk9d78hZvEjybZ6zrdTr1E7zwHJVO7UGpf4_43SChOFcGBzABAYAbQwH8FEP-ZRNRH9Ik3ir0NSuFJVjuXV6rXxAIlVoF1myDrQoCsLZxwXdXv1Q_PfzZiXxNdXvhk6hfq1slZqAtCfryyb9Wz8T/s728-e365/app-d.png)](https://thehackernews.uk/EUN089)
The root cause of the vulnerability, per the cybersecurity firm, is a combination of [session fixation](https://owasp.org/www-community/attacks/Session_fixation) on the web management panel of AWS MWAA and an AWS domain misconfiguration that results in a cross-site scripting ([XSS](https://owasp.org/www-community/attacks/xss/)) attack.


Session fixation is a [web attack technique](https://cwe.mitre.org/data/definitions/384.html) that occurs when a user is authenticated to a service without invalidating any existing session identifiers. This permits the adversary to [force](https://en.wikipedia.org/wiki/Session_fixation) (aka fixate) a known session identifier on a user so that, once the user authenticates, the attacker has access to the authenticated session.


[![Session Hijacking](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjILz0xjT5ptU_C1KazscJgnshKd8vP9LYyFF81SMJXhPaTWWvSRAkjDobNH6dmXggcMcHpCBaVU7UDtIEIoZmB0EB1ZrnHT_dOzp4_NeW7Gweb0EN4JbFD-RufGVH_gtFxveBAW3IUJT7qvlscZoh6zSG6Pp8ZgQgEo58hSstucjzz-IyPtav7P2Ljh9zu/s728-rw-e365/rr.jpg)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjILz0xjT5ptU_C1KazscJgnshKd8vP9LYyFF81SMJXhPaTWWvSRAkjDobNH6dmXggcMcHpCBaVU7UDtIEIoZmB0EB1ZrnHT_dOzp4_NeW7Gweb0EN4JbFD-RufGVH_gtFxveBAW3IUJT7qvlscZoh6zSG6Pp8ZgQgEo58hSstucjzz-IyPtav7P2Ljh9zu/s728-rw-e365/rr.jpg)
By abusing the shortcoming, a threat actor could have forced victims to use and authenticate the attacker's known session and ultimately take over the victim's web management panel.


"FlowFixation highlights a broader issue with the current state of cloud providers' domain architecture and management as it relates to the Public Suffix List ([PSL](https://publicsuffix.org/)) and shared-parent domains: same-site attacks," Matan said, adding the misconfiguration also impacts Microsoft Azure and Google Cloud.


Tenable also pointed out that the shared architecture – where several customers have the same parent domain – could be a goldmine for attackers looking to exploit vulnerabilities like same-site attacks, cross-origin issues, and [cookie tossing](https://0xn3va.gitbook.io/cheat-sheets/web-application/cookie-security/cookie-tossing), effectively leading to unauthorized access, data leaks, and code execution.


[![Cybersecurity](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiq3FD_K5jS19OiNrl_zJkHFPA5uRlxhWj-jrr23FY6-XPfhWmbo9d2hGEAU7haozVp8oJP6WDTShcroe-tunJMeq5PVdoOrePEC_-bzW8DlT4Dpp7r5CvIyQxabciMuLITAu8SQT6OeFR8bKOS4GQ32wteZFU8KG6c8a54AY-I7hO5w6Pc-Fzeun9pPY4w/s728-rw-e3650/cis-d.png)](https://thehackernews.uk/cis-hardened-images-platforms)
The shortcoming has been addressed by both AWS and Azure adding the misconfigured domains to PSL, thus causing web browsers to recognize the added domains as a public suffix. Google Cloud, on the other hand, has described the issue as not "severe enough" to merit a fix.


"In the case of same-site attacks, the security impact of the mentioned domain architecture is significant, with heightened risk of such attacks in cloud environments," Matan explained.


"Among these, cookie-tossing attacks and same-site attribute cookie protection bypass are particularly concerning as both can circumvent CSRF protection. Cookie-tossing attacks can also abuse session-fixation issues."


  





## Tags:


### Autogenerated tags:
[[aws]] [[cloud]] [[same-site]] [[mwaa]] [[matan]]
