# HTTP/2 Rapid Reset Zero-Day Vulnerability Exploited to Launch Record DDoS Attacks
## ⚡ Beware of the HTTP/2 Rapid Reset attack! A novel zero-day flaw is being exploited to launch record-breaking distributed denial-of-service (DDoS).
## Information:

+ Link: https://thehackernews.com/2023/10/http2-rapid-reset-zero-day.html
+ Source: The Hacker News
+ Author: Newsroom
+ Date published: 10 October 2023, 20:54
+ Date scraped: 10 October 2023, 16:01

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEgOCLs23FAiBC9ZvPX1-a2IFf1Nu8OQT8-bkgSoM2MyZ3XOxx6QzWA7ZaHlMk9E4JODhVtEzJ8i5KlgyKS6R3ZYb2EZ4m4HCllGj9rQMX7sQs75BLJw7cWrhcsoWOS2wRo4s_cxTqA4wCSYHzLNB1pTc34Gmz5G8tB365LvvrFfWO0Dt8zpy9IDE-jhGzYz/s728-rw-ft-e30/ddos.jpg)


Amazon Web Services (AWS), Cloudflare, and Google on Tuesday said they took steps to mitigate record-breaking distributed denial-of-service (DDoS) attacks that relied on a novel technique called HTTP/2 Rapid Reset.


The [layer 7 attacks](https://www.cloudflare.com/learning/ddos/application-layer-ddos-attack/) were detected in late August 2023, the companies said in a coordinated disclosure. The cumulative susceptibility to this attack is being tracked as [**CVE-2023-44487**](https://nvd.nist.gov/vuln/detail/CVE-2023-44487), and carries a CVSS score of 7.5 out of a maximum of 10.


While the attacks aimed at Google's cloud infrastructure peaked at [398 million requests per second](https://cloud.google.com/blog/products/identity-security/google-cloud-mitigated-largest-ddos-attack-peaking-above-398-million-rps) (RPS), the ones aimed at AWS and Cloudflare exceeded a volume of 155 million and 201 million requests per second (RPS), respectively.


HTTP/2 Rapid Reset refers to a zero-day flaw in the HTTP/2 protocol that can be exploited to carry out DDoS attacks. A significant feature of HTTP/2 is multiplexing requests over a single TCP connection, which manifests in the form of concurrent streams.


What's more, a client that wants to abort a request can issue a [RST\_STREAM frame](https://httpwg.org/specs/rfc7540.html#RST_STREAM) to halt the data exchange. The Rapid Reset attack leverages this method to send and cancel requests in quick succession, thereby circumventing the server's concurrent stream maximum and overloading the server without reaching its configured threshold.


"HTTP/2 rapid reset attacks consist of multiple HTTP/2 connections with requests and resets in rapid succession," Mark Ryland and Tom Scholl at AWS [said](https://aws.amazon.com/blogs/security/how-aws-protects-customers-from-ddos-events/).


"For example, a [series of requests](https://aws.amazon.com/security/security-bulletins/AWS-2023-011/) for multiple streams will be transmitted followed up by a reset for each of those requests. The targeted system will parse and act upon each request, generating logs for a request that is then reset, or canceled, by a client."


This ability to reset streams immediately allows each connection to have an indefinite number of requests in flight, thereby enabling a threat actor to issue a barrage of HTTP/2 requests that can overwhelm a targeted website's capability to respond to new incoming requests, effectively taking it down.


[![HTTP/2 Rapid Reset Zero-Day Vulnerability](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEi_U63BEe0i4PMZO9Ro_WlR-waPi3QLKunyuJzEWBWWyyChxUHHKZ3VbR2nc2rDuliFbWsYcXJP0QoQcWqWzrLv_Gt9FTQYiiucMZAkbtHc0Zh9z_Moan_85io-rFAx-cCPl4ETEJD-SH-YR12voLZqUSOQCsfi264340yIqREw8wSp56a7TQkGdjiJdzdb/s728-rw-ft-e30/map.jpg)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEi_U63BEe0i4PMZO9Ro_WlR-waPi3QLKunyuJzEWBWWyyChxUHHKZ3VbR2nc2rDuliFbWsYcXJP0QoQcWqWzrLv_Gt9FTQYiiucMZAkbtHc0Zh9z_Moan_85io-rFAx-cCPl4ETEJD-SH-YR12voLZqUSOQCsfi264340yIqREw8wSp56a7TQkGdjiJdzdb/s728-rw-ft-e30/map.jpg)
Put differently, by initiating hundreds of thousands of HTTP/2 streams and rapidly canceling them at scale over an established connection, threat actors can overwhelm websites and knock them offline. Another crucial aspect is that such attacks can be pulled off using a modestly-sized botnet, something to tune of 20,000 machines as observed by Cloudflare.


"This zero-day provided threat actors with a [critical new tool](https://blog.cloudflare.com/technical-breakdown-http2-rapid-reset-ddos-attack/) in their Swiss Army knife of vulnerabilities to exploit and attack their victims at a magnitude that has never been seen before," Grant Bourzikas, chief security officer at Cloudflare, [said](https://blog.cloudflare.com/zero-day-rapid-reset-http2-record-breaking-ddos-attack/).


HTTP/2 is used by 35.6% of all the websites, according to [W3Techs](https://w3techs.com/technologies/details/ce-http2). The percentage of requests that use HTTP/2 is at 77%, per data shared by [Web Almanac](https://almanac.httparchive.org/en/2022/http).


Google Cloud said it has observed multiple variants of the Rapid Reset attacks that while not as effective as the initial version, are more efficient than the standard HTTP/2 DDoS attacks.


"The first variant does not immediately cancel the streams, but instead opens a batch of streams at once, waits for some time, and then cancels those streams and then immediately opens another large batch of new streams," Juho Snellman and Daniele Lamartino [said](https://cloud.google.com/blog/products/identity-security/how-it-works-the-novel-http2-rapid-reset-ddos-attack).


"The second variant does away with canceling streams entirely, and instead optimistically tries to open more concurrent streams than the server advertised."


F5, in an [independent advisory](https://www.f5.com/company/blog/http-2-rapid-reset-attack-impacting-f5-nginx-products) of its own, said the attack impacts the NGINX HTTP/2 module and has urged its customers to update their NGINX configuration to limit the number of concurrent streams to a default of 128 and persist HTTP connections for up to 1000 requests.


"After today, threat actors will be largely aware of the HTTP/2 vulnerability; and it will inevitably become trivial to exploit and kickoff the race between defenders and attacks — first to patch vs. first to exploit," Bourzikas further said. "Organizations should assume that systems will be tested, and take proactive measures to ensure protection."


  





## Tags:
***CVE's***: CVE-2023-44487

### Autogenerated tags:
[[http/2]] [[cloudflare]] [[aws]] [[google]] [[ddos]]
