# The Rise of S3 Ransomware: How to Identify and Combat It
## The Rise of S3 Ransomware: How to Identify and Combat It | Read more hacking news on The Hacker News cybersecurity news website and learn how to protect against cyberattacks and software vulnerabilities.
## Information:

+ Link: https://thehackernews.com/2023/10/the-rise-of-s3-ransomware-how-to.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 25 October 2023, 17:06
+ Date scraped: 25 October 2023, 13:01

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhewBynsWBJz5qGxgCvRt6qSQfAfweKFKWu4iiIUI86NacQNBfriT6fIpk54G623Bh3oCFPfip_5_k7a1GBloja4nfhGpJgxEYNk4QvR0Ybu3EHuzGM0sKkmiSfplTXjroS4Yp0dVGarvDd_weGVez4N6x62X-MDaAG1p3hgsLw5QOKPeTXxkT12E-2lLg/s728-rw-ft-e30/ransomware.jpg)


In today's digital landscape, around [60%](https://www.statista.com/statistics/1062879/worldwide-cloud-storage-of-corporate-data/) of corporate data now resides in the cloud, with Amazon S3 standing as the backbone of data storage for many major corporations. 


Despite S3 being a secure service from a reputable provider, its pivotal role in handling vast amounts of sensitive data (customer personal information, financial data, intellectual property, etc.), provides a juicy target for threat actors. It remains susceptible to ransomware attacks which are often initiated using leaked access keys that have accidentally been exposed by human error and have access to the organization's buckets.


To effectively combat these evolving threats, it is vital to ensure that your organization has visibility into your S3 environment, that you are aware of how threat actors can compromise data for ransom and most importantly, best practices for minimizing the risk of cyber criminals successfully executing such an attack.


**Ensuring Visibility: CloudTrail and Server Access Logs**[#](#ensuring-visibility-cloudtrail-and-server-access-logs)
---------------------------------------------------------------------------------------------------------------------


Visibility serves as the foundation for any effective detection strategy. In Amazon S3, nearly every action translates to an API call, which are meticulously recorded in CloudTrail and documented in AWS documentation.


The two primary options for logging activity in S3 buckets — CloudTrail Data Events and Server Access Logs — hold a wealth of information that security practitioners must leverage to anticipate and detect suspicious activity. Each offer distinct advantages and trade-offs:


* Cloud Trail Data Events: offer visibility into resource operations performed on or within a resource in real-time, but comes with potential cost implications due to high API call volumes
* Server Access Logs: free access to records for each request made to your S3 bucket, but come with potential delays in log availability and potential logging with less integrity.


![CloudTrail](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEg6G0sZ5G1uXRBJhXIA29UYb2L5rIR2sBQTYsBmitC9PHty0sy4k5hZ2K1GvmyaDCmBlvZcqCxavtj2E5287a3qUhz49svGzmzNeSUCX7jup8QeLy6boSvQQnOYrcdk4Pxc-O8DIQI14dvLyPCiefi8vY3C9fmXNwMXa0itfdMbvzhrLr2ikB0Z44h1Voo/s728-rw-ft-e30/log.png)
**Mitigating Risk by Understanding the Attack Scenarios**[#](#mitigating-risk-by-understanding-the-attack-scenarios)
--------------------------------------------------------------------------------------------------------------------


Utilizing the above logs to ensure adequate visibility, it is possible to keep an eye out for potential attack scenarios in order to mitigate risks effectively. There are three main attack scenarios that we observe with S3 ransomware attacks, all which can prevent an organization from accessing its data. Below are the attack scenarios, along with links to hunting queries that the expert threat hunting team from Hunters' [Team Axon](https://www.hunters.security/team-axon) has shared publicly that allow anyone to search for these attack scenarios within their own environments:


1. Object Encryption: ransomware commonly involves file encryption to deny an organization access to their files, harm business operations and demand ransom for getting the files back
1. Hunting Query: <https://github.com/axon-git/threat-hunting-tools/blob/main/S3%20Ransomware/s3_ransomware_objects_encrypted_with_a_kms_key_not_owned_by_the_organization.sql>

3. Object Deletion - Delete Operations: deleting all objects from a bucket is an easy way for threat actors to have a major impact on business operations, improving the chances of victims paying ransoms
1. Hunting Query: <https://github.com/axon-git/threat-hunting-tools/blob/main/S3%20Ransomware/s3_ransomware_unauthorized_object_deletions.sql>

5. Object Deletion - Lifecycle Policy: a less straightforward but quieter way to delete files in Cloudtrail that still offers high chances of a paid ransom
1. Hunting Query: <https://github.com/axon-git/threat-hunting-tools/blob/main/S3%20Ransomware/s3_ransomware_unauthorized_deletion_using_bucket_lifecycle.sql>


*\*Note: Object Encryption and Object Deletion - Delete Operations require enabling Cloudtrail Data Events for the appropriate buckets.*

 Each scenario poses significant disruptions, potentially preventing organizations from accessing critical data. By delving into the required permissions, attacker perspectives, and detection methods for each scenario, organizations can proactively prepare for potential threats.


**Protection and Best Practices**[#](#protection-and-best-practices)
--------------------------------------------------------------------


Understanding the attack scenarios helps to provide context for how to implement proactive measures to significantly reduce the attack surface. There are several things that can be done to enhance the security of S3 buckets from the threat of ransomware.


* Use IAM roles for short-term credentials: avoid using static IAM access keys. If you are using IAM users, be sure to enable Multi-Factor Authentication (MFA) for them.
* Follow the principle of least privilege: this ensures that users and roles only possess the permissions necessary for their tasks. Additionally, utilize bucket policies to restrict access to these essential resources.
* Enable S3 Versioning: this means keeping record of every version of every object stored in your bucket instead of directly modifying it. This is very effective against unauthorized override or deletions.
* Enable S3 Object Lock: operating on a write-once, read-many (WORM) model, means that your data cannot be deleted by anyone (the data is "locked") which safeguards against modifications for defined time periods.
* Set up AWS Backup/Bucket Replication: this can be any form of backup that is separate in location and access control from your actual bucket.
* Implement server-side encryption with AWS KMS keys: this provides your organization with specific control over who can access bucket objects. This supplies yet another level of protection against who can encrypt and decrypt objects in your bucket.


**Conclusion**[#](#conclusion)
------------------------------


As data volumes continue to surge, securing Amazon S3 is paramount in safeguarding millions of organizations against ransomware attacks and evolving cyber threats.


Prioritizing threats, ensuring visibility through CloudTrail and Server Access Logs, and implementing proactive measures are essential steps in mitigating risk. By adopting these strategies, organizations can fortify their S3 buckets' protection and ensure the integrity and security of their critical data.


For a more in depth breakdown of common attack scenarios and best practices, check out a [video deep dive](https://www.youtube.com/watch?v=8lljel4GgYU) from Team Axon. Team Axon is the expert threat hunting arm of the popular SIEM replacement [Hunters](https://www.hunters.security/), and offers rapid response to emerging cyber threats, on-demand cyber expertise and proactive threat hunting across customers' environments. [Follow Team Axon on X](https://twitter.com/team__axon) for timely updates on emerging cyber threats and premiere cyber content.


#### **Additional S3 Resources:**[#](#additional-s3-resources)


* [AWS Customer Playbook (GitHub)](https://github.com/aws-samples/aws-customer-playbook-framework/blob/main/docs/Ransom_Response_S3.md)
* [Incident Response Workshop for S3 ransomware (AWS)](https://catalog.workshops.aws/aws-cirt-ransomware-simulation-and-detection/en-US)


  





## Tags:
***urls***: https://github.com/axon-git/threat-hunting-tools/blob/main/S3%20Ransomware/s3_ransomware_objects_encrypted_with_a_kms_key_not_owned_by_the_organization.sql https://github.com/axon-git/threat-hunting-tools/blob/main/S3%20Ransomware/s3_ransomware_unauthorized_object_deletions.sql https://github.com/axon-git/threat-hunting-tools/blob/main/S3%20Ransomware/s3_ransomware_unauthorized_deletion_using_bucket_lifecycle.sql

### Autogenerated tags:
[[s3]] [[ransomware]] [[cloudtrail]] [[aws]] [[iam]]
