# Critical RCE Bug in Spring Could Be the Next Log4Shell, Researchers Warn
## The so-called 'Spring4Shell' bug has cropped up, so to speak, and could be lurking in literally millions of Java applications.
## Information:

+ Link: https://kasperskycontenthub.com/threatpost-global/?p=179173
+ Source: ThreatPost
+ Author: Tara Seals
+ Date published: 30 March 2022, 18:04
+ Date scraped: 30 March 2022, 19:00

## Article:
![Main article image](https://media.threatpost.com/wp-content/uploads/sites/103/2022/03/30140258/spring-scaled-e1648663405854.jpeg)


A critical security vulnerability has bloomed in the Spring Cloud Function, which could lead to remote code execution (RCE) and the compromise of an entire internet-connected host.


Researchers have dubbed it “Spring4Shell” due to its ubiquitous nature, a la the [Log4Shell vulnerability](https://threatpost.com/log4jshell-swarm-vmware-servers-miners-backdoors/179142/) discovered in December.


“Spring4Shell is another in a series of major Java vulnerabilities,” Stefano Chierici, a security researcher at Sysdig, noted in materials shared with Threatpost. “It has a very low bar for exploitation so we should expect to see attackers heavily scanning the internet. Once found, they will likely install cryptominers, [distributed denial-of-service] DDoS agents, or their remote-access toolkits.”


[![Infosec Insiders Newsletter](https://media.threatpost.com/wp-content/uploads/sites/103/2021/07/10165815/infosec_insiders_in_article_promo.png)](https://threatpost.com/infosec-insider-subscription-page/?utm_source=ART&utm_medium=ART&utm_campaign=InfosecInsiders_Newsletter_Promo/)


The bug (CVE-2022-22963, with a CVSS vulnerability-severity score of 9.0 out of 10) affects versions 3.1.6 and 3.2.2, as well as older, unsupported versions, according to a [Tuesday advisory](https://spring.io/blog/2022/03/29/cve-report-published-for-spring-cloud-function). Users should update to [3.1.7](https://repo.maven.apache.org/maven2/org/springframework/cloud/spring-cloud-function-context/3.1.7/) and [3.2.3](https://repo.maven.apache.org/maven2/org/springframework/cloud/spring-cloud-function-context/3.2.3/) in order to implement a patch.


## **Widescale Consequences Set to Sprout**


Spring Cloud is an open-source microservices framework: A collection of ready-to-use components which are useful in building distributed applications in an enterprise. It’s [widely used across industries](https://spring.io/projects/spring-cloud) by various companies and includes ready-made integration with components from various app providers, including Kubernetes and Netflix.


As such, it’s footprint is vast, according to Sysdig.


“Spring is…used by millions of developers using Spring Framework to create high-performing, easily testable code,” Chierici said. “The Spring Cloud Function framework allows developers to write cloud-agnostic functions using Spring features. These functions can be stand-alone classes and one can easily deploy them on any cloud platform to build a serverless framework.”


He added, “Since Spring Cloud Function can be used in Cloud serverless functions like AWS lambda or Google Cloud Functions, those functions might be impacted as well…leading the attackers inside your cloud account.”


## **The CVE-2022-22963 Bug in Bloom**


According to Sysdig, the vulnerability can be exploited over HTTP: Just like Log4Shell, it only requires an attacker to send a malicious string to a Java app’s HTTP service.


“Using routing functionality, it is possible for a user to provide a specially crafted Spring Expression Language (SpEL) as a routing-expression to access local resources and execute commands in the host,” Chierici explained. “The issue with CVE-2022-22963 is that it permits using HTTP request header spring.cloud.function.routing-expression parameter and SpEL expression to be injected and executed through StandardEvaluationContext.”


As such, unfortunately, an exploit is “quite easy to accomplish” using a simple curl command he noted:


*curl -i -s -k -X $’POST’ -H $’Host: 192.168.1.2:8080′ -H $’spring.cloud.function.routing-expression:T(java.lang.Runtime).getRuntime().exec(\”touch /tmp/test”)’ –data-binary $’exploit\_poc’ $’http://192.168.1.2:8080/functionRouter’*


*<CURL>*


Sysdig published a proof-of-concept (PoC) on its GitHub page.


## **Weeding Out Compromises**


After applying the patch, anyone using applications built using Spring Cloud should take a careful inventory of their installations to make sure compromise hasn’t already occurred, according to Sysdig.


“Even though you might have already upgraded your library or applied one of the other mitigations on containers affected by the vulnerability, you need to detect any exploitation attempts and post-breach activities in your environment,” Chierici said.


That detection can be done via image scanners or a runtime detection engine to suss out malicious behaviors in already-deployed hosts or pods, he noted.


“The best defense for this type of vulnerability is to patch as soon as possible,” according to Sysdig’s writeup. “Having a clear understanding of the packages being used in your environment is a must in today’s world.”


***Moving to the cloud? Discover emerging cloud-security threats along with solid advice for how to defend your assets with our***[***FREE downloadable eBook***](https://bit.ly/3Jy6Bfs)***, “Cloud Security: The Forecast for 2022.”*** ***We explore organizations’ top risks and challenges, best practices for defense, and advice for security success in such a dynamic computing environment, including handy checklists.***


 





## Tags:
***CVE's***: CVE-2022-22963
***ipv4-adresses***: 192.168.1.2
***urls***: http://192.168.1.2:8080/functionRouter

### Autogenerated tags:
[[cloud]] [[sysdig]] [[chierici]] [[cve-2022-22963]] [[http]]
